/**
 * IUEditor.js v2.0.15
 * document : https://iueditor-cdn.s3.amazonaws.com/js/readme.html
 */

/**
 IE9 : javascript only works after opening developer tools (because console is undefined)
 */
if (typeof window.console == "undefined") {
    window.console = {
        log: function() {}
    };
}

/**
 * manage iueditor information
 */
var IUEditor = {
    /**
     * Major version of IUEditor build.
     * @property majorVersion
     * @type String
     */
    majorVersion: '2',
    /**
     * Minor version of IUEditor build.
     * @property minorVersion
     * @type String
     */
    minorVersion: '0',
    /**
     * Fix version of IUEditor build.
     * @property fixVersion
     * @type String
     */
    fixVersion: '15',
    /**
     * @property releaseDate
     * @type String
     */
    releaseDate: '2016-07-18',

    print: function() {
        var self = this;
        console.log('IUEditor(v' + self.majorVersion + '.' + self.minorVersion + '.' + self.fixVersion + '), Released:' + self.releaseDate);
    }
};

var IU_WIDGET = {
    CAROUSEL: 'iu.carousel',
    COLLAPSIBLE: 'iu.collapsible',
    FLIPSWITCH: 'iu.flipswitch',
    GOOGLEMAP: 'iu.googlemap',
    PANEL: 'iu.panel',
    POPUP: 'iu.popup',
    RANGE_SLIDER: 'iu.rangeslider',
    SLIDER: 'iu.slider',
    TABVIEW: 'iu.tabview',
    TEXT: 'iu.text',
    TRANSITION: 'iu.transition',
    SWITCH: 'iu.switch',
    MOVIE: 'iu.movie',
    WEBMOVIE: 'iu.webmovie',
    SCROLL_EVENT: 'iu.scrollevent',
    //wordpress widget
    WP_MENU: 'wp.menu'
}

/**
IUEditor signature
*/
console.log();
/**
 * Check List
 * jQuery, velocity, velocity-ui 
 * jQuery plugin 
 */

/*
 * IUEditor : IUCarousel 
 * Needs plugin : jQuery, velocity, velocity-ui, plugin/jquery.event.move, plugin/jquery.iu
 */

+ function($) {
    'use strict';
    //custom class
    var IU_CAROUSEL_WRAPPER_CLASS = '.iux-carousel-wrapper';
    var IU_CAROUSEL_PAGER_CLASS = '.iux-carousel-pager';
    var IU_CAROUSEL_PREV_CLASS = '.iux-carousel-prev';
    var IU_CAROUSEL_NEXT_CLASS = '.iux-carousel-next';
    var IU_ACTIVE_CLASS_NAME = 'iux-active';
    var IU_CAROUSEL_COPY_CLASS_NAME = 'carousel-copy';

    //data
    var IU_CAROUSEL_DATA_TIME = 'iu-carousel-time';


    var Carousel = function(element) {


        this.$element = $(element)
        this.isLoaded = null
        this.$wrapper = $(element).find(IU_CAROUSEL_WRAPPER_CLASS);
        this.$pager = $(element).find(IU_CAROUSEL_PAGER_CLASS);

        //index
        this.itemIndex = null; //carousel item index
        this.pagerIndex = null; //pager index 

        //autoplay
        this.timer = null;
        this.itemCount = null;
        this.timerDuration = $(element).data(IU_CAROUSEL_DATA_TIME);
        this.isAutoplay = element.hasAttribute('data-' + IU_CAROUSEL_DATA_TIME);

        //css name
        var ieVersion = window.getInternetExplorerVersion();
        this.isLeft = ieVersion <= 9 && ieVersion >= 0 ? true : false;
        this.xTag = this.isLeft ? 'margin-left' : 'translateX';

        //auto height - set as default
        this.height = 0;

    }


    Carousel.prototype.reload = function() {
        this.destroy();
        this.init();
    }

    Carousel.prototype.init = function() {
        var self = this;
        if (self.isLoaded) {
            return;
        };

        //check balance between items and pagers
        var itemCount = self.$wrapper.children().length;
        var pagerCount = self.$pager.children().length;

        //count of pagers is not equal to the number of items
        if (itemCount != pagerCount) {
            if (pagerCount > itemCount) {
                //remove redundant pagers
                self.$pager.children().slice(itemCount, pagerCount).remove();
            } else {
                //add pagers
                for (var i = 0; i < itemCount - pagerCount; i++) {
                    self.$pager.append($('<li></li>'));
                }

            }
        }

        if (itemCount < 2) {
            //if the number of items < 2, not working in carousel
            //just put on, and hide control of carousel
            self.$element.children().not(self.$wrapper).css('display', 'none');
            return;
        };

        //set item count
        self.itemCount = itemCount;

        //set carousel loaded
        self.isLoaded = true;

        //copy first & last item
        var firstObj = $(self.$wrapper.children()[0]).clone(true);
        firstObj.addClass(IU_CAROUSEL_COPY_CLASS_NAME);

        var lastObj = $(self.$wrapper.children()[itemCount - 1]).clone(true);
        lastObj.addClass(IU_CAROUSEL_COPY_CLASS_NAME);

        //insert copy objects
        $(firstObj).insertAfter($(self.$wrapper.children()[itemCount - 1]));
        $(lastObj).insertBefore($(self.$wrapper.children()[0]));

        //set position & size
        //1.  wrapper size & position
        var width = 100 * (self.itemCount + 2);
        window.requestAnimFrame(function() {
            self.$wrapper.css('width', width + '%');
        });

        var left = self.xPosForIndex(1);
        $.Velocity.hook(self.$wrapper, self.xTag, left);

        //2. item size
        var childrenWidth = 100 / (itemCount + 2);
        self.$wrapper.children().each(function() {
            var child = this;
            window.requestAnimFrame(function() {
                $(child).css('width', childrenWidth + '%');
            });

        });

        //set index
        self.itemIndex = 1;
        self.pagerIndex = 0;

        //set event delegation
        //click binding
        self.$element.find(IU_CAROUSEL_PREV_CLASS).click(function() {
            self.pause();
            self.movePrev();
            self.start();
        });

        self.$element.find(IU_CAROUSEL_NEXT_CLASS).click(function() {
            self.pause()
            self.moveNext();
            self.start();
        });

        //activate pager
        self.activate();

        /* caoursel item binding */
        self.$element.on({
            movestart: function(e) {
                // If the movestart is heading off in an upwards or downwards
                // direction, prevent it so that the browser scrolls normally.
                if ((e.distX > e.distY && e.distX < -e.distY) ||
                    (e.distX < e.distY && e.distX > -e.distY)) {
                    e.preventDefault();
                }
                self.pause()
            },
            move: function(e) {
                // Move slides with the finger
                self.moveXCarouselItem(e.distX);
            },
            moveend: function(e) {
                self.endMoveCarouselItem(e.distX);
                self.start();
            }
        });
        self.$element.find(IU_CAROUSEL_PAGER_CLASS + '>li').on({
            click: function(e) {
                self.pause();
                var index = self.$pager.children().index(this);
                self.move(index + 1);
                self.start();
                e.preventDefault();
            }
        })

        //start timer
        self.start();

        // adjust height
        self.adjustHeight(self.itemIndex);


    }

    Carousel.prototype.resize = function() {
        var self = this;
        if (self.isLoaded) {
            var xPos = self.xPosForIndex(self.itemIndex);
            var velocityDict = self.isLeft ? {
                'margin-left': xPos
            } : {
                'translateX': xPos
            };
            self.$wrapper.velocity(velocityDict, {
                duration: 0
            });

            var currentItem = $(self.$wrapper.children()[self.itemIndex])
            var height = currentItem.height();
            window.requestAnimFrame(function() {
                self.$element.css('height', height + 'px');
            })
        };
    }

    Carousel.prototype.pause = function() {
        var self = this;
        if (self.isLoaded && self.isAutoplay) {
            window.clearInterval(self.timer);
            self.timer = null;
        }
    }

    Carousel.prototype.start = function() {
        var self = this;
        if (self.isLoaded && self.isAutoplay && self.timerDuration) {
            //set timer
            self.timer = window.setInterval(function() {
                self.moveNext();
            }, self.timerDuration);
        }
    }

    Carousel.prototype.destory = function() {
        var self = this;
        if (self.isLoaded) {
            var copyItems = self.$wrapper.find('.' + IU_CAROUSEL_COPY_CLASS_NAME);
            copyItems.remove();
        };
    }

    Carousel.prototype.moveNext = function() {
        var index = this.itemIndex + 1;
        this.move(index);
    }

    Carousel.prototype.moveCurrent = function() {
        var index = this.itemIndex;
        this.move(index);
    }

    Carousel.prototype.movePrev = function() {
        var index = this.itemIndex - 1;
        this.move(index);
    }

    /**
    @param toIndex : carousel이 움직일 index 
    @param translateX  : 해당 value가 있으면 해당 위치로 옮긴다. (to Index와 같이 있어야함)
    */
    Carousel.prototype.move = function(toIndex, diffX) {
        var self = this;
        //check doing animation
        if (self.$wrapper.hasClass('velocity-animating')) {
            return;
        };

        //save current index
        self.itemIndex = toIndex;
        if (toIndex == 0) { //last
            self.pagerIndex = self.itemCount - 1;
        } else if (toIndex > self.itemCount) {
            self.pagerIndex = 0;
        } else {
            self.pagerIndex = toIndex - 1;
        }

        //pager activate
        self.activate();

        //move left
        var moveX = diffX != undefined ? diffX : self.xPosForIndex(toIndex);
        var velocityDict = self.isLeft ? {
            'margin-left': moveX
        } : {
            'translateX': moveX
        };

        var xTag = self.xTag;
        self.$wrapper.velocity(velocityDict, {
            duration: 400,
            complete: function() {

                //move last, first item to original item
                if (toIndex == 0) {
                    self.itemIndex = self.itemCount;

                } else if (toIndex > self.itemCount) {
                    self.itemIndex = 1;
                }

                var x = self.xPosForIndex(self.itemIndex);
                $.Velocity.hook(self.$wrapper, self.xTag, x);

                self.adjustHeight(toIndex);
                
            }
        })


    }

    Carousel.prototype.adjustHeight = function(index){
        var self = this;
        //set height of carousel equal to current item
        var height = $(self.$wrapper.children()[index]).height();
        if (self.height != height) {
            $.Velocity.hook(self.$element, 'height', height + 'px');
            self.height = height;
        };
    }

    Carousel.prototype.xPosForIndex = function(index) {
        var self = this;
        var x;
        if (self.isLeft) {
            // left에서는 다른 parent 기준임.
            x = 100 * index * -1;
        } else {
            x = (100 / (self.itemCount + 2)) * index * -1;
        }
        return x + '%';
    }

    Carousel.prototype.activate = function() {
        var self = this;
        var pagerIndex = self.pagerIndex;

        //select li class active
        self.$pager.children().each(function(i) {
            if (i == pagerIndex) {
                $(this).addClass(IU_ACTIVE_CLASS_NAME);
            } else {
                $(this).removeClass(IU_ACTIVE_CLASS_NAME);
            }
        });
    }

    Carousel.prototype.moveXCarouselItem = function(distX) {
        var self = this;
        var currentX = self.$wrapper.width() / (self.itemCount + 2) * self.itemIndex * -1;
        var moveX = currentX + distX;
        $.Velocity.hook(self.$wrapper, self.xTag, moveX + 'px');

    }

    Carousel.prototype.endMoveCarouselItem = function(distX) {
        var self = this;
        var itemWidth = self.$wrapper.width() / (self.itemCount + 2);
        //carousel 의 qurter를 기준으로 함.
        var index;
        if (Math.abs(distX) > itemWidth / 4) {
            if (distX < 0) {
                index = self.itemIndex + 1;
            } else {
                index = self.itemIndex - 1;
            }
        } else {
            index = self.itemIndex;
        }
        var currentX = self.$wrapper.width() / (self.itemCount + 2) * index * -1;
        // %으로 하면 움직일때 px에서 화면이 팅기는 현상이 발생하기 때문에 pixel값을 넘겨준다.
        self.move(index, currentX + 'px');
    }


    // CAROUSEL PLUGIN
    function Plugin() {
        return this.each(function() {
            var $this = $(this);
            var carousel = $this.data(IU_WIDGET.CAROUSEL);
            if (!carousel) {
                carousel = new Carousel(this);
                $this.data(IU_WIDGET.CAROUSEL, carousel);
                carousel.init();
            };
        })
    }

    $.fn.carousel = Plugin
    $.fn.carousel.Constructor = Carousel

    // CAROUSEL READY 
    $(document).ready(function() {
        //$('.iu-carousel').carousel();
    });
}(jQuery)



/*
 * IUEditor : IUCollapsible 
 * Needs plugin : jQuery, plugin/jquery.iu
 */

+ function($) {
    'use strict';

    //iu class
    var IU_COLLAPSIBLE_HEADER_CLASS = '.iu-collapsible-header';
    var IU_COLLAPSIBLE_CONTENT_CLASS = '.iu-collapsible-content';
    var IU_COLLAPSIBLE_HEADER_ITEM_CLASS = '.iu-collapsible-header-item';

    //data name
    var IU_COLLAPSIBLE_DATA_ANIMATION = 'iu-show-animation';
    var IU_COLLAPSIBLE_DATA_DURATION = 'iu-show-duration';
    var IU_COLLAPSIBLE_DATA_METHOD = 'iu-event-method';

    var Collapsible = function(element) {

        this.$element = $(element);
        this.$header = $(element).children().filter(IU_COLLAPSIBLE_HEADER_CLASS);
        this.$content = $(element).children().filter(IU_COLLAPSIBLE_CONTENT_CLASS);
        var headerItems = this.$header.children().filter(IU_COLLAPSIBLE_HEADER_ITEM_CLASS);
        this.$defaultHeader = $(headerItems[0]);

        //check header
        if (headerItems.length > 1) {
            this.$activeHeader = $(headerItems[1]);
            this.hasTwoHeader = true;
        } else {
            this.hasTwoHeader = false;
        }

        //attribute
        this.animation = $(element).data(IU_COLLAPSIBLE_DATA_ANIMATION);
        this.duration = parseFloat($(element).data(IU_COLLAPSIBLE_DATA_DURATION)) * 1000;
        this.state = false; //collapsible open state state (collapsed - false)
        this.isShowing = false;
        this.isClosing = false;
        this.eventType = this.$element.data(IU_COLLAPSIBLE_DATA_METHOD);

		this.id = $(element).attr('id');

    }

    Collapsible.prototype.init = function() {
        var self = this;
		//binding
        //mousehover binding
        if (self.eventType == 'mouseon') {
            var isMobile = window.mobileAndTabletcheck();
            if (isMobile) {
                self.$element.on({
                    touchstart: function() {
                        if (self.isShowing || self.isClosing) {
                            return;
                        }
                        self.toggle(true);
                    },
                    touchcancel: function() {
                        if (self.isClosing) {
                            return;
                        }
                        self.toggle(false);
                    },
                    touchend: function() {
                        if (self.isClosing) {
                            return;
                        }
                        self.toggle(false);
                    }
                });
            } else {
                self.$element.on({
                    mouseenter: function() {
                        if (self.isShowing || self.isClosing) {
                            return;
                        }
                        self.toggle(true);
                    },
                    mouseleave: function() {
                        if (self.isClosing) {
                            return;
                        }
                        self.toggle(false);
                    }
                });
            }
        }else if(self.eventType == 'justClose'){
			self.$header.on({
				click: function() {
					if (self.isShowing || self.isClosing) {
						return;
					}
					if(self.state){
						self.toggle();
					}
				}
			})
		}else if(self.eventType == 'justCloseAndCssChange'){

			var realId = self.id.replace("_collapsible","");
			self.$header.on({
				click: function() {
					if (self.isShowing || self.isClosing) {
						return;
					}
					if(self.state){
						$('#'+realId+'_up').show();
						$('#'+realId+'_down').hide();
						self.toggle();
					}
				}
			})
		}
        //click binding
        else {
            self.$header.on({
                click: function() {
                    if (self.isShowing || self.isClosing) {
                        return;
                    }
                    self.toggle();
                }
            })
        }
    }

    Collapsible.prototype.toggle = function(state) {
        var self = this;

        if (typeof(state) == 'undefined' || state == null) {
            state = !self.state;
        };

        if (self.hasTwoHeader) {
            if (state) {
                self.$defaultHeader.css('display', 'none');
                self.$activeHeader.css('display', 'block');
            } else {
                self.$defaultHeader.css('display', 'block');
                self.$activeHeader.css('display', 'none');
            }
        }
        var callback;
        if (state) {
            self.isShowing = true;
            callback = function() {
                self.isShowing = false;
            };
        } else {
            self.isClosing = true;
            callback = function() {
                self.isClosing = false;
            };
        }
        self.$content.velocityToggle(state, self.animation, self.duration, {}, callback);
        self.state = state;
    }

    // COLLAPSIBLE PLUGIN
    function Plugin() {
        return this.each(function() {
            var $this = $(this);
            var collapsible = $this.data(IU_WIDGET.COLLAPSIBLE);
            if (!collapsible) {
                collapsible = new Collapsible(this);
                $this.data(IU_WIDGET.COLLAPSIBLE, collapsible)
                collapsible.init();
            };
        })
    }

    $.fn.collapsible = Plugin
    $.fn.collapsible.Constructor = Collapsible

    // COLLAPSIBLE READY
    $(document).ready(function() {
        $('.iu-collapsible').collapsible();

    });

}(jQuery)


/*
 * IUEditor : IUFlipSwitch 
 * Needs plugin : jQuery, velocity
 */
+ function($) {

    'use strict';

    var Flipswitch = function(element) {
        this.$element = $(element)
            //TODO : 조절
        this.$input = $($(element).children()[0])
        this.$wrapper = $($(element).children()[1])
        this.$button = $($(element).children()[2])

        this.checked = this.$input[0].checked;
        this.duration = 300;

    }

    Flipswitch.prototype.init = function() {
        //set initial state
        this.toggle(this.checked, 0);

        //set intialstate
        this.$element.css('visibility', '');

        var self = this;
        this.$element.on({
            click: function() {
                self.toggle();
            }
        })
    }

    Flipswitch.prototype.toggle = function(state, duration) {
        var self = this;
        //velocity check
        if (self.$element.children().hasClass('velocity-animating')) {
            //wait until former animation
            return;
        };
        if (duration == undefined) {
            duration = self.duration;
        };

        if (state == undefined) {
            state = !self.checked;
        };

        var $wrapper = self.$wrapper;
        var $moveelements = $([self.$wrapper, self.$button]);
        var width = self.$element.width();
        var buttonWidth = self.$button.outerWidth();


        if (state) {
            //set intial translate (natural move)
            var buttonLeft = self.$button.position().left;
            var wrapperInitialX = -1 * width + buttonLeft + buttonWidth;
            $.Velocity.hook($wrapper, 'translateX', wrapperInitialX + 'px');

            //set animation
            $wrapper.velocity({
                translateX: '0px'
            }, {
                duration: duration,
                complete: function() {
                    self.$input[0].checked = true;
                    self.checked = true;
                }

            })
            var buttonX = width - buttonLeft * 2 - buttonWidth;
            self.$button.velocity({
                translateX: buttonX + 'px'
            }, {
                duration: duration,
            });
        } else {
            //set intial translate (natural move)
            var wrapperInitialX = -1 * (buttonWidth);
            $.Velocity.hook($wrapper, 'translateX', wrapperInitialX + 'px');

            //set animation
            var translateX = width * -1;
            $wrapper.velocity({
                translateX: translateX + 'px'
            }, {
                duration: duration,
                complete: function() {
                    self.$input[0].checked = false;
                    self.checked = false;
                }
            });
            self.$button.velocity({
                translateX: '0px'
            }, {
                duration: duration,
            });

        }

    }

    // FLIP SWITCH PLUGIN
    function Plugin() {
        return this.each(function() {
            var $this = $(this);
            var flipswitch = $this.data(IU_WIDGET.FLIPSWITCH);
            if (!flipswitch) {
                flipswitch = new Flipswitch(this);
                $this.data(IU_WIDGET.FLIPSWITCH, flipswitch);
                flipswitch.init();
            };
        })
    }

    $.fn.flipswitch = Plugin
    $.fn.flipswitch.Constructor = Flipswitch

    //FLIP SWITCH READY
    $(document).ready(function() {
        $('.iu-pg-flip-switch').flipswitch();
    })

}(jQuery);




/*
 * IUEditor : IUSection with fullsize 
 * Needs plugin : jQuery, plugin/jquery.iu
 */

+ function($) {

    'use strict';

    // shim layer with setTimeout fallback
    window.requestAnimFrame = (function() {
        return window.requestAnimationFrame ||
            window.webkitRequestAnimationFrame ||
            window.mozRequestAnimationFrame ||
            function(callback) {
                window.setTimeout(callback, 1000 / 60);
            };
    })();

    // WINDOW EVENT
    var oldHeight;
    $(window).resize(function(event) {
        var height = window.innerHeight;
        if (oldHeight == undefined) {
            oldHeight = height;
        };

        if (oldHeight != height) {
            $('.iu-section[data-iu-full-section]').iufullsection();
            oldHeight = height;
        };
    })

    // SECTION PLUGIN

    $.fn.iufullsection = function resize() {
        var height = window.innerHeight;

        return this.each(function() {
            var self = this;
            window.requestAnimFrame(function() {
                self.style.height = height + 'px';
            });
        })
    }

    // SECTION READY
    $(document).ready(function() {
        $('.iu-section[data-iu-full-section]').iufullsection();

    })


}(jQuery)



/*
 * IUEditor : IUGoogleMap 
 * Needs plugin : jQuery, googlemap ref: //maps.googleapis.com/maps/api/js?v=3.exp&sensor=true'
 */
+ function($) {
    'use strict';

    //data
    var IU_MAP_DATA_LATITUDE = 'iu-map-latitude';
    var IU_MAP_DATA_LONGITUDE = 'iu-map-longitude';
    var IU_MAP_DATA_ZOOM_LEVEL = 'iu-map-zoom-level';
    var IU_MAP_DATA_ZOOM = 'iu-map-zoom';
    var IU_MAP_DATA_STREET_CONTROL = 'iu-map-street';
    var IU_MAP_DATA_THEME = 'iu-map-theme';
    var IU_MAP_DATA_ICON = 'iu-map-icon';
    var IU_MAP_DATA_MARKER_PATH = 'iu-map-marker-path';
    var IU_MAP_DATA_MAP_TITLE = 'iu-map-title';


    //gogole map prototype
    var GoogleMap = function(element) {
        this.$element = $(element);
        this.latitude = parseFloat($(element).data(IU_MAP_DATA_LATITUDE));
        this.longitude = parseFloat($(element).data(IU_MAP_DATA_LONGITUDE));
        this.zoomLevel = $(element).data(IU_MAP_DATA_ZOOM_LEVEL);
        this.zoomControl = $(element).data(IU_MAP_DATA_ZOOM);
        this.streetControl = $(element).data(IU_MAP_DATA_STREET_CONTROL);
        this.map = null;

    }

    GoogleMap.prototype.init = function() {
        var self = this;

        //style
        var styleIndex = parseInt(self.$element.data(IU_MAP_DATA_THEME));
        var style;
        if (styleIndex > 0) {
            style = self.getStyle(styleIndex - 1);
        }

        //option
        var option = {
            center: new google.maps.LatLng(self.latitude, self.longitude),
            zoom: self.zoomLevel,
            zoomControl: self.zoomControl,
            mapTypeControl: false,
            streetViewControl: self.streetControl,
            styles: style
        };

        //create map
        var map = new google.maps.Map(self.$element[0], option);

        //add marker icon
        if (self.$element.data(IU_MAP_DATA_ICON)) {
            var iconImagePath = self.$element.data(IU_MAP_DATA_MARKER_PATH);
            var marker;
            if (iconImagePath != undefined) {
                marker = new google.maps.Marker({
                    map: map,
                    position: map.getCenter(),
                    icon: iconImagePath
                });
            } else {
                marker = new google.maps.Marker({
                    map: map,
                    position: map.getCenter()
                });
            }

            //click infomation
            var title = self.$element.data(IU_MAP_DATA_MAP_TITLE);
            if (title != undefined) {
                var infoWindow = new google.maps.InfoWindow();
                infoWindow.setContent('<p>' + title + '</p>');
                google.maps.event.addListener(marker, 'click', function() {
                    infoWindow.open(map, marker);
                });
            }
        }

        //add event listner : (resize)
        google.maps.event.addListener(window, "resize", function() {
            var center = new google.maps.LatLng(self.latitude, self.longitude);
            google.maps.event.trigger(map, "resize");
            map.setCenter(center);
        });

        self.map = map;
    }

    GoogleMap.prototype.resize = function() {
        var center = new google.maps.LatLng(this.latitude, this.longitude);
        google.maps.event.trigger(this.map, "resize");
        map.setCenter(center);
    }

    GoogleMap.prototype.getStyle = function(index) {
        var themeList = [
            //paledawn
            [{
                "featureType": "water",
                "stylers": [{
                    "visibility": "on"
                }, {
                    "color": "#acbcc9"
                }]
            }, {
                "featureType": "landscape",
                "stylers": [{
                    "color": "#f2e5d4"
                }]
            }, {
                "featureType": "road.highway",
                "elementType": "geometry",
                "stylers": [{
                    "color": "#c5c6c6"
                }]
            }, {
                "featureType": "road.arterial",
                "elementType": "geometry",
                "stylers": [{
                    "color": "#e4d7c6"
                }]
            }, {
                "featureType": "road.local",
                "elementType": "geometry",
                "stylers": [{
                    "color": "#fbfaf7"
                }]
            }, {
                "featureType": "poi.park",
                "elementType": "geometry",
                "stylers": [{
                    "color": "#c5dac6"
                }]
            }, {
                "featureType": "administrative",
                "stylers": [{
                    "visibility": "on"
                }, {
                    "lightness": 33
                }]
            }, {
                "featureType": "road"
            }, {
                "featureType": "poi.park",
                "elementType": "labels",
                "stylers": [{
                    "visibility": "on"
                }, {
                    "lightness": 20
                }]
            }, {}, {
                "featureType": "road",
                "stylers": [{
                    "lightness": 20
                }]
            }],
            //subtlegrayscale
            [{
                "featureType": "landscape",
                "stylers": [{
                    "saturation": -100
                }, {
                    "lightness": 65
                }, {
                    "visibility": "on"
                }]
            }, {
                "featureType": "poi",
                "stylers": [{
                    "saturation": -100
                }, {
                    "lightness": 51
                }, {
                    "visibility": "simplified"
                }]
            }, {
                "featureType": "road.highway",
                "stylers": [{
                    "saturation": -100
                }, {
                    "visibility": "simplified"
                }]
            }, {
                "featureType": "road.arterial",
                "stylers": [{
                    "saturation": -100
                }, {
                    "lightness": 30
                }, {
                    "visibility": "on"
                }]
            }, {
                "featureType": "road.local",
                "stylers": [{
                    "saturation": -100
                }, {
                    "lightness": 40
                }, {
                    "visibility": "on"
                }]
            }, {
                "featureType": "transit",
                "stylers": [{
                    "saturation": -100
                }, {
                    "visibility": "simplified"
                }]
            }, {
                "featureType": "administrative.province",
                "stylers": [{
                    "visibility": "off"
                }]
            }, {
                "featureType": "water",
                "elementType": "labels",
                "stylers": [{
                    "visibility": "on"
                }, {
                    "lightness": -25
                }, {
                    "saturation": -100
                }]
            }, {
                "featureType": "water",
                "elementType": "geometry",
                "stylers": [{
                    "hue": "#ffff00"
                }, {
                    "lightness": -25
                }, {
                    "saturation": -97
                }]
            }],
            //bluegray
            [{
                "featureType": "water",
                "stylers": [{
                    "visibility": "on"
                }, {
                    "color": "#b5cbe4"
                }]
            }, {
                "featureType": "landscape",
                "stylers": [{
                    "color": "#efefef"
                }]
            }, {
                "featureType": "road.highway",
                "elementType": "geometry",
                "stylers": [{
                    "color": "#83a5b0"
                }]
            }, {
                "featureType": "road.arterial",
                "elementType": "geometry",
                "stylers": [{
                    "color": "#bdcdd3"
                }]
            }, {
                "featureType": "road.local",
                "elementType": "geometry",
                "stylers": [{
                    "color": "#ffffff"
                }]
            }, {
                "featureType": "poi.park",
                "elementType": "geometry",
                "stylers": [{
                    "color": "#e3eed3"
                }]
            }, {
                "featureType": "administrative",
                "stylers": [{
                    "visibility": "on"
                }, {
                    "lightness": 33
                }]
            }, {
                "featureType": "road"
            }, {
                "featureType": "poi.park",
                "elementType": "labels",
                "stylers": [{
                    "visibility": "on"
                }, {
                    "lightness": 20
                }]
            }, {}, {
                "featureType": "road",
                "stylers": [{
                    "lightness": 20
                }]
            }],
            //green
            [{
                "featureType": "landscape",
                "elementType": "geometry.fill",
                "stylers": [{
                    "color": "#bbd5c5"
                }]
            }, {
                "featureType": "road.local",
                "elementType": "geometry.stroke",
                "stylers": [{
                    "color": "#808080"
                }]
            }, {
                "featureType": "road.highway",
                "elementType": "geometry.fill",
                "stylers": [{
                    "color": "#fcf9a2"
                }]
            }, {
                "featureType": "poi",
                "elementType": "geometry.fill",
                "stylers": [{
                    "color": "#bbd5c5"
                }]
            }, {
                "featureType": "road.highway",
                "elementType": "geometry.stroke",
                "stylers": [{
                    "color": "#808080"
                }]
            }],
            //Ultra Light with Labels
            [{
                "featureType": "water",
                "elementType": "geometry",
                "stylers": [{
                    "color": "#e9e9e9"
                }, {
                    "lightness": 17
                }]
            }, {
                "featureType": "landscape",
                "elementType": "geometry",
                "stylers": [{
                    "color": "#f5f5f5"
                }, {
                    "lightness": 20
                }]
            }, {
                "featureType": "road.highway",
                "elementType": "geometry.fill",
                "stylers": [{
                    "color": "#ffffff"
                }, {
                    "lightness": 17
                }]
            }, {
                "featureType": "road.highway",
                "elementType": "geometry.stroke",
                "stylers": [{
                    "color": "#ffffff"
                }, {
                    "lightness": 29
                }, {
                    "weight": 0.2
                }]
            }, {
                "featureType": "road.arterial",
                "elementType": "geometry",
                "stylers": [{
                    "color": "#ffffff"
                }, {
                    "lightness": 18
                }]
            }, {
                "featureType": "road.local",
                "elementType": "geometry",
                "stylers": [{
                    "color": "#ffffff"
                }, {
                    "lightness": 16
                }]
            }, {
                "featureType": "poi",
                "elementType": "geometry",
                "stylers": [{
                    "color": "#f5f5f5"
                }, {
                    "lightness": 21
                }]
            }, {
                "featureType": "poi.park",
                "elementType": "geometry",
                "stylers": [{
                    "color": "#dedede"
                }, {
                    "lightness": 21
                }]
            }, {
                "elementType": "labels.text.stroke",
                "stylers": [{
                    "visibility": "on"
                }, {
                    "color": "#ffffff"
                }, {
                    "lightness": 16
                }]
            }, {
                "elementType": "labels.text.fill",
                "stylers": [{
                    "saturation": 36
                }, {
                    "color": "#333333"
                }, {
                    "lightness": 40
                }]
            }, {
                "elementType": "labels.icon",
                "stylers": [{
                    "visibility": "off"
                }]
            }, {
                "featureType": "transit",
                "elementType": "geometry",
                "stylers": [{
                    "color": "#f2f2f2"
                }, {
                    "lightness": 19
                }]
            }, {
                "featureType": "administrative",
                "elementType": "geometry.fill",
                "stylers": [{
                    "color": "#fefefe"
                }, {
                    "lightness": 20
                }]
            }, {
                "featureType": "administrative",
                "elementType": "geometry.stroke",
                "stylers": [{
                    "color": "#fefefe"
                }, {
                    "lightness": 17
                }, {
                    "weight": 1.2
                }]
            }],
            //Shades of Grey
            [{
                "featureType": "all",
                "elementType": "labels.text.fill",
                "stylers": [{
                    "saturation": 36
                }, {
                    "color": "#000000"
                }, {
                    "lightness": 40
                }]
            }, {
                "featureType": "all",
                "elementType": "labels.text.stroke",
                "stylers": [{
                    "visibility": "on"
                }, {
                    "color": "#000000"
                }, {
                    "lightness": 16
                }]
            }, {
                "featureType": "all",
                "elementType": "labels.icon",
                "stylers": [{
                    "visibility": "off"
                }]
            }, {
                "featureType": "administrative",
                "elementType": "geometry.fill",
                "stylers": [{
                    "color": "#000000"
                }, {
                    "lightness": 20
                }]
            }, {
                "featureType": "administrative",
                "elementType": "geometry.stroke",
                "stylers": [{
                    "color": "#000000"
                }, {
                    "lightness": 17
                }, {
                    "weight": 1.2
                }]
            }, {
                "featureType": "landscape",
                "elementType": "geometry",
                "stylers": [{
                    "color": "#000000"
                }, {
                    "lightness": 20
                }]
            }, {
                "featureType": "poi",
                "elementType": "geometry",
                "stylers": [{
                    "color": "#000000"
                }, {
                    "lightness": 21
                }]
            }, {
                "featureType": "road.highway",
                "elementType": "geometry.fill",
                "stylers": [{
                    "color": "#000000"
                }, {
                    "lightness": 17
                }]
            }, {
                "featureType": "road.highway",
                "elementType": "geometry.stroke",
                "stylers": [{
                    "color": "#000000"
                }, {
                    "lightness": 29
                }, {
                    "weight": 0.2
                }]
            }, {
                "featureType": "road.arterial",
                "elementType": "geometry",
                "stylers": [{
                    "color": "#000000"
                }, {
                    "lightness": 18
                }]
            }, {
                "featureType": "road.local",
                "elementType": "geometry",
                "stylers": [{
                    "color": "#000000"
                }, {
                    "lightness": 16
                }]
            }, {
                "featureType": "transit",
                "elementType": "geometry",
                "stylers": [{
                    "color": "#000000"
                }, {
                    "lightness": 19
                }]
            }, {
                "featureType": "water",
                "elementType": "geometry",
                "stylers": [{
                    "color": "#000000"
                }, {
                    "lightness": 17
                }]
            }],
            //Muted Blue
            [{
                "featureType": "all",
                "stylers": [{
                    "saturation": 0
                }, {
                    "hue": "#e7ecf0"
                }]
            }, {
                "featureType": "road",
                "stylers": [{
                    "saturation": -70
                }]
            }, {
                "featureType": "transit",
                "stylers": [{
                    "visibility": "off"
                }]
            }, {
                "featureType": "poi",
                "stylers": [{
                    "visibility": "off"
                }]
            }, {
                "featureType": "water",
                "stylers": [{
                    "visibility": "simplified"
                }, {
                    "saturation": -60
                }]
            }],
            //Unsaturated Browns
            [{
                "elementType": "geometry",
                "stylers": [{
                    "hue": "#ff4400"
                }, {
                    "saturation": -68
                }, {
                    "lightness": -4
                }, {
                    "gamma": 0.72
                }]
            }, {
                "featureType": "road",
                "elementType": "labels.icon"
            }, {
                "featureType": "landscape.man_made",
                "elementType": "geometry",
                "stylers": [{
                    "hue": "#0077ff"
                }, {
                    "gamma": 3.1
                }]
            }, {
                "featureType": "water",
                "stylers": [{
                    "hue": "#00ccff"
                }, {
                    "gamma": 0.44
                }, {
                    "saturation": -33
                }]
            }, {
                "featureType": "poi.park",
                "stylers": [{
                    "hue": "#44ff00"
                }, {
                    "saturation": -23
                }]
            }, {
                "featureType": "water",
                "elementType": "labels.text.fill",
                "stylers": [{
                    "hue": "#007fff"
                }, {
                    "gamma": 0.77
                }, {
                    "saturation": 65
                }, {
                    "lightness": 99
                }]
            }, {
                "featureType": "water",
                "elementType": "labels.text.stroke",
                "stylers": [{
                    "gamma": 0.11
                }, {
                    "weight": 5.6
                }, {
                    "saturation": 99
                }, {
                    "hue": "#0091ff"
                }, {
                    "lightness": -86
                }]
            }, {
                "featureType": "transit.line",
                "elementType": "geometry",
                "stylers": [{
                    "lightness": -48
                }, {
                    "hue": "#ff5e00"
                }, {
                    "gamma": 1.2
                }, {
                    "saturation": -23
                }]
            }, {
                "featureType": "transit",
                "elementType": "labels.text.stroke",
                "stylers": [{
                    "saturation": -64
                }, {
                    "hue": "#ff9100"
                }, {
                    "lightness": 16
                }, {
                    "gamma": 0.47
                }, {
                    "weight": 2.7
                }]
            }],
            //light dream
            [{
                "featureType": "landscape",
                "stylers": [{
                    "hue": "#FFBB00"
                }, {
                    "saturation": 43.400000000000006
                }, {
                    "lightness": 37.599999999999994
                }, {
                    "gamma": 1
                }]
            }, {
                "featureType": "road.highway",
                "stylers": [{
                    "hue": "#FFC200"
                }, {
                    "saturation": -61.8
                }, {
                    "lightness": 45.599999999999994
                }, {
                    "gamma": 1
                }]
            }, {
                "featureType": "road.arterial",
                "stylers": [{
                    "hue": "#FF0300"
                }, {
                    "saturation": -100
                }, {
                    "lightness": 51.19999999999999
                }, {
                    "gamma": 1
                }]
            }, {
                "featureType": "road.local",
                "stylers": [{
                    "hue": "#FF0300"
                }, {
                    "saturation": -100
                }, {
                    "lightness": 52
                }, {
                    "gamma": 1
                }]
            }, {
                "featureType": "water",
                "stylers": [{
                    "hue": "#0078FF"
                }, {
                    "saturation": -13.200000000000003
                }, {
                    "lightness": 2.4000000000000057
                }, {
                    "gamma": 1
                }]
            }, {
                "featureType": "poi",
                "stylers": [{
                    "hue": "#00FF6A"
                }, {
                    "saturation": -1.0989010989011234
                }, {
                    "lightness": 11.200000000000017
                }, {
                    "gamma": 1
                }]
            }]

        ];

        return themeList[index];
    }

    //GOOGLE MAP PLUGIN
    function Plugin() {
        return this.each(function() {
            var $this = $(this);
            var googlemap = $this.data(IU_WIDGET.GOOGLEMAP);
            if (!googlemap) {
                googlemap = new GoogleMap(this);
                $this.data(IU_WIDGET.GOOGLEMAP, googlemap);
                googlemap.init();
            };
        })
    }

    $.fn.googlemap = Plugin
    $.fn.googlemap.Constructor = GoogleMap

    $(document).ready(function() {
        $('.iu-googlemap').googlemap();

    });
}(jQuery);



/*
 * IUEditor : IUPanel 
 * Needs plugin : jQuery, velocity, plugin/jquery.iu
 */

+ function($) {

    'use strict';

    //SET CONSTANT STRING
    //id
    var IU_PANEL_DIM_ID = '#iux-panel-dimcolor';

    //class
    var IU_PAGE_CLASS = '.iu-page';
    var IU_CLOSE_BUTTON_CLASS = '.iux-panel-close-button';
    var IU_FIXED_SIZE_CLASS_NAME = 'iux-fixed-one-size';

    //data
    var IU_PANEL_DATA_DIRECTION = 'iu-panel-direction';
    var IU_PANEL_DATA_ANIMATION = 'iu-show-animation';
    var IU_PANEL_DATA_DURATION = 'iu-show-duration';

    var IU_PANEL_DATA_EXTERN_NAME = 'data-iu-panel-extern-closed';


    //document's singleton element
    var $dimElement;
    var $pageElement;
    var oldScrollTop;

    function disableScroll() {
        oldScrollTop = $(document).scrollTop();
        window.requestAnimFrame(function() {
            $pageElement.css('margin-top', -oldScrollTop + 'px');
            $pageElement.addClass(IU_FIXED_SIZE_CLASS_NAME);
        });

    }

    function enableScroll() {

        $pageElement.css({
            'margin-top': '',
            'transform': ''
        });

        $pageElement.removeClass(IU_FIXED_SIZE_CLASS_NAME);
        $(document).scrollTop(oldScrollTop);
    }

    //PANEL PROTOTYPE

    var Panel = function(element) {
        this.$element = $(element);
        this.direction = parseInt($(element).data(IU_PANEL_DATA_DIRECTION)); //0 : left, 1: right //TODO : 
        this.animation = $(element).data(IU_PANEL_DATA_ANIMATION);
        this.duration = parseFloat($(element).data(IU_PANEL_DATA_DURATION)) * 1000;
        this.isAnimating = false;
        this.dimClass = element.id + '-dimcolor';
        this.state = false; //true - shown, false - closed
        this.isExternalClosed = element.hasAttribute(IU_PANEL_DATA_EXTERN_NAME);
    }


    Panel.prototype.init = function() {
        var self = this;
        var $closeButton = this.$element.children().filter(IU_CLOSE_BUTTON_CLASS);
        $closeButton.on({
            click: function() {
                self.close();
            }
        })
    }

    Panel.prototype.reset = function() {

    }

    Panel.prototype.close = function() {
        var self = this;

        //ignore animate state
        if (self.isAnimating) {
            return;
        };
        //ignore off state
        if (!self.state) {
            return;
        };
        self.isAnimating = true;

        var animation = self.animation;
        var css = {
            'translateX': '0px'
        };

        var closeCallbackFn = function() {
            self.isAnimating = false;
            self.state = false;
            window.requestAnimFrame(function() {

                //update page
                enableScroll();

                //update dim element
                $.Velocity.hook($dimElement[0], 'display', 'none');
                $dimElement.removeClass(self.dimClass);
            });
        }

        var option = {
            duration: self.duration,
            complete: closeCallbackFn
        };

        if (animation == 'overlay') {
            //panel
            self.$element.velocity(css, option);

        } else if (animation == 'reveal') {
            //page
            $pageElement.css('z-index', '');
            $pageElement.velocity(css, option);

        } else if (animation == 'push') {
            //panel
            self.$element.velocity(css, option);
            //page
            $pageElement.velocity(css, option);
        }

        //update dim element
        $dimElement.velocity({
            opacity: 0
        }, {
            duration: this.duration
        });


    }

    Panel.prototype.show = function() {
        var self = this;

        //ignore animate state
        if (self.isAnimating) {
            return;
        };
        //ignore on state
        if (self.state) {
            return;
        };

        self.isAnimating = true;
        disableScroll();

        var width = self.$element.outerWidth();
        var left = self.direction == 0 ? width : -1 * width;
        var animation = self.animation;

        var option = {};
        var css = {};

        css['translateX'] = left + 'px';

        option['complete'] = function() {
            self.isAnimating = false;
            self.state = true;
        }

        if (animation == 'overlay') {
            //panel
            self.$element.velocity(css, option);

        } else if (animation == 'reveal') {
            //page
            //change option complete
            option['complete'] = function() {
                self.isAnimating = false;
                self.state = true;
                var panelZIndex = parseInt(self.$element.css('z-index'));
                $pageElement.css('z-index', panelZIndex - 1);
            }
            $pageElement.velocity(css, option);

        } else if (animation == 'push') {
            //TODO: page css for panel 
            $pageElement.css({
                '-webkit-backface-visibility': 'hidden',
                '-moz-backface-visibility': 'hidden',
                'backface-visibility': 'hidden'
            });
            //panel
            self.$element.velocity(css, option);
            //page
            $pageElement.velocity(css, option);
        }



        //check dim color action
        $dimElement.css({
            display: 'block',
            opacity: 0
        });
        $dimElement.addClass(self.dimClass);
        $dimElement.velocity({
            opacity: 1
        }, {
            duration: self.duration
        });


    }

    Panel.prototype.toggle = function() {
        if (this.state) {
            this.close();
        } else {
            this.show();
        }
    }



    // PANEL PLUGIN
    function Plugin() {
        return this.each(function() {
            var $this = $(this);
            var panel = $this.data(IU_WIDGET.PANEL);
            if (!panel) {
                panel = new Panel(this);
                $this.data(IU_WIDGET.PANEL, panel);
                panel.init();
            };
        })
    }

    $.fn.panel = Plugin
    $.fn.panel.Constructor = Panel

    // PANEL READY

    function initPanelComponent($element){
        $dimElement = $element.find(IU_PANEL_DIM_ID);
        $pageElement = $element.find(IU_PAGE_CLASS);

        //initialize panel
        $element.find('.iu-panel').panel();

        //set panel button delegation
        $element.find('.iux-panel-button').on({
            click: function() {
                var panelId = $(this).data('iu-panel-id');
                var $panelEl = $('#' + panelId);
                var panel = $panelEl.data(IU_WIDGET.PANEL);
                if (panel) {
                    panel.toggle();
                };

            }
        });

        //initialize dim color delegation
        $dimElement.on({
            click: function() {
                var $elements = $('.iu-panel');
                $elements.each(function() {
                    var panel = $(this).data(IU_WIDGET.PANEL);
                    if (panel.state && panel.isExternalClosed) {
                        panel.close();
                    };
                })
            }
        })
    }

    // PANEL READY
    $(document).ready(function() {
        initPanelComponent($("body"));
    })

    window.IUEditor.initPanelComponent = initPanelComponent;


}(jQuery)


/*
 * IUEditor : IUPopup 
 * Needs plugin : jQuery, velocity, plugin/jquery.iu
 */

+ function($) {

    'use strict';

    //SET CONSTANT STRING
    //id
    var IU_POPUP_DIM_ID = '#iux-popup-dimcolor';

    //class
    var IU_PAGE_CLASS = '.iu-page';
    var IU_POPUP_CLASS = '.iu-popup';
    var IU_CLOSE_BUTTON_CLASS = '.iux-popup-close-button';
    var IU_FIXED_SIZE_CLASS_NAME = 'iux-fixed-one-size';

    //data
    var IU_POPUP_DATA_ANIMATION = 'iu-show-animation';
    var IU_POPUP_DATA_DURATION = 'iu-show-duration';

    var IU_POPUP_DATA_EXTERN_NAME = 'data-iu-popup-extern-closed';


    //singleton element in document
    var $dimElement;
    var $pageElement;

    var oldScrollTop;

    function disableScroll() {
        oldScrollTop = $(document).scrollTop();
        window.requestAnimFrame(function() {
            $pageElement.css('margin-top', -oldScrollTop + 'px');
            $pageElement.addClass(IU_FIXED_SIZE_CLASS_NAME);
        });

    }

    function enableScroll() {
        $pageElement.css({
            'margin-top': '',
            'transform': '',
        });
        $pageElement.removeClass(IU_FIXED_SIZE_CLASS_NAME);
        window.scrollTo(0, oldScrollTop);

    }


    //POPUP PROTOTYPE

    var Popup = function(element) {
        this.$element = $(element);
        this.direction = $(element).data(IU_POPUP_DATA_ANIMATION) == 'top-down' ? 0 : 1 //0 : topdown , 1 : bottomup
        this.duration = parseFloat($(element).data(IU_POPUP_DATA_DURATION)) * 1000;
        this.isAnimating = false;
        this.dimClass = element.id + '-dimcolor';
        this.state = false; //true - shown, false - closed
        this.isExternalClosed = element.hasAttribute(IU_POPUP_DATA_EXTERN_NAME);
    }


    Popup.prototype.init = function() {
        //set initial position
        $.Velocity.hook(this.$element[0], 'translateX', '-50%');
        $.Velocity.hook(this.$element[0], 'translateY', this.hiddenY() + 'px');

        var self = this;
        //delegate close button
        var $closeButton = this.$element.children().filter(IU_CLOSE_BUTTON_CLASS);
        $closeButton.on({
            click: function() {
                self.close();
            }
        })
    }

    Popup.prototype.hiddenY = function() {
        //In ios, window.outerHeight == 0
        var wHeight = window.outerHeight == 0 ? window.innerHeight : window.outerHeight;
        // mobile issue : (address toolbar - 50px의 여유분을 둠)
        var top = this.direction == 0 ? (wHeight / 2 + this.$element[0].offsetHeight + 50) * -1 : wHeight / 2 + 50;
        return top;
    }

    Popup.prototype.reset = function() {
        var self = this;
        var translateY;
        if (self.state) {
            translateY = '-50%';
        } else {
            translateY = self.hiddenY() + 'px';
        }

        $.Velocity.hook(self.$element[0], 'translateY', translateY);

    }

    /**
    top-down의 경우 덜 숨겨진 상태가 있으므로 한번더 update하도록 한다. 
    */
    Popup.prototype.checkHide = function() {
        var self = this;
        if (!self.state) {
            $.Velocity.hook(self.$element[0], 'translateY', self.hiddenY() + 'px');
        }
    }

    Popup.prototype.close = function() {
        //ignore animate state
        if (this.isAnimating) {
            return;
        };
        //ignore off state
        if (!this.state) {
            return;
        };

        this.isAnimating = true;


        var self = this;
        var top = this.hiddenY();
        var css = {
            'translateY': top + 'px'
        };


        var closeCompleteFn = function() {
            self.state = false;
            self.isAnimating = false;
            window.requestAnimFrame(function() {

                self.$element.css('visibility', 'hidden');
                //update page
                enableScroll();

                //dimelement
                $.Velocity.hook($dimElement[0], 'display', 'none');
                $dimElement.removeClass(self.dimClass);
            });
        }

        var option = {
            duration: this.duration,
            complete: closeCompleteFn
        };


        $.Velocity.hook(self.$element[0], 'translateY', (-1) * this.$element[0].offsetHeight / 2 + 'px');
        this.$element.velocity(css, option);


        //update dim element
        $dimElement.velocity({
            opacity: 0
        }, {
            duration: this.duration
        });

    	// add by hyyumi
    	setBtnFocusable(); // 포커스 이동 
    }

    Popup.prototype.show = function() {
        var self = this;
        self.$element.css('visibility', 'visible');
        //ignore animate state
        if (self.isAnimating) {
            return;
        };
        //ignore on state
        if (self.state) {
            return;
        };

        self.isAnimating = true;
        disableScroll();

        var css = {};
        css['translateY'] = (-1) * self.$element[0].offsetHeight / 2 + 'px';
        var option = {
            duration: self.duration,
            complete: function() {
                self.isAnimating = false;
                self.state = true;
                $.Velocity.hook(self.$element[0], 'translateY', '-50%');


            }
        }

        //popup
        self.$element.velocity(css, option);


        //check dim color action
        $dimElement.css({
            display: 'block',
            opacity: 0
        });
        $dimElement.addClass(self.dimClass);
        $dimElement.velocity({
            opacity: 1
        }, {
            duration: self.duration
        });

    	// add by hyyumi
    	setBtnFocusable(-1, this); // 포커스 이동 
    }

    Popup.prototype.toggle = function() {
        if (this.state) {
            this.close();
        } else {
            this.show();
        }
    }



    // POPUP PLUGIN
    function Plugin() {
        return this.each(function() {
            var $this = $(this);
            var popup = $this.data(IU_WIDGET.POPUP);
            if (!popup) {
                popup = new Popup(this);
                $this.data(IU_WIDGET.POPUP, popup);
                popup.init();
            };
        })
    }

    $.fn.popup = Plugin
    $.fn.popup.Constructor = Popup

    // window resize
    $(window).resize(function() {
        $(IU_POPUP_CLASS).each(function() {
            var popup = $(this).data(IU_WIDGET.POPUP);
            if (popup) {
                popup.reset();
            };
        })
    })

    // window load
    $(window).load(function() {
        $(IU_POPUP_CLASS).each(function() {
            var popup = $(this).data(IU_WIDGET.POPUP);
            if (popup) {
                popup.checkHide();
            }
        })
    })

    // POPUP READY
    function initPopupComponent($element){

        $dimElement = $element.find(IU_POPUP_DIM_ID);
        $pageElement = $element.find(IU_PAGE_CLASS);

        $element.find(IU_POPUP_CLASS).popup();
        $element.find('.iux-popup-button').on({
            click: function() {
                var popupId = $(this).data('iu-popup-id');
                var $popupEl = $('#' + popupId);
                var popup = $popupEl.data(IU_WIDGET.POPUP);
                if (popup) {
                    popup.toggle();
                }
            }
        });

		/* DIM 처리 한곳에서 재 클릭시 DIM 풀림 방지*/
        /*$dimElement.on({
            click: function() {
                var $popupEls = $element.find(IU_POPUP_CLASS);
                $popupEls.each(function() {
                    var popup = $(this).data(IU_WIDGET.POPUP);
                    if (popup.state && popup.isExternalClosed) {
                        popup.close();
                    }
                })
            }
        })*/
    }

    $(document).ready(function() {
        initPopupComponent($("body"));
    })

    //export
    window.IUEditor.initPopupComponent = initPopupComponent;

}(jQuery)


/*
 * IUEditor : IURangeSlider 
 * Needs plugin : jQuery, plugin/jquery.iu
 */

+ function($) {

    'use strict';

    var Rangeslider = function(element) {
        //slide elements
        this.$element = $(element)

        //TODO : children이 안들어가면 find대신에 children/filter로 변경
        this.$slidebar = $(element).find('.iu-pg-range-slide-bar')
        this.$innerbar = this.$slidebar.find('.iux-pg-range-slidebar-innerbar')
        this.$startPoint = this.$innerbar.find('.iu-pg-range-slide-point-start')
        this.$endPoint = this.$innerbar.find('.iu-pg-range-slide-point-end')
        this.$startTextfield = $(element).find('.iu-pg-range-slide-text-field-start')
        this.$endTextField = $(element).find('.iu-pg-range-slide-text-field-end')

        //data
        this.max = $(element).data('iu-slide-max-value')
        this.min = $(element).data('iu-slide-min-value')
        this.startValue = $(element).data('iu-range-slide-default-start-value')
        this.endValue = $(element).data('iu-range-slide-default-end-value')
        this.size = this.max - this.min

        //data for event
        this.eventInfo = {
            isTouching: false,
            touchStartX: null,
            isDragging: false,
            dragStartX: null,
            isStartPoint: false,
            isEndPoint: false,
        }
    }

    var activeSlider = null;

    Rangeslider.prototype.init = function() {

        //set event delegate
        var self = this;
        //TODO : isMobile?을 체크해야 하나? 그냥 다쓰면안되는건가?
        var bindingOption = {
            touchstart: function(event) {
                self.touchStart(event);
                event.preventDefault();
            },
            touchmove: function(event) {
                self.touchMove(event);
                event.preventDefault();
            },
            touchend: function(event) {
                self.touchEnd(event);
                event.preventDefault();
            },
            touchcancle: function(event) {
                self.touchEnd(event);
                event.preventDefault();
            },
            mousedown: function(event) {
                self.mousedown(event);
                event.preventDefault();
            },
            mousemove: function(event) {
                self.mousemove(event);
                event.preventDefault();
            },
            mouseup: function(event) {
                self.mouseup(event);
                event.preventDefault();
            }
        }

        this.$slidebar.on(bindingOption);

        this.$startTextfield.on({
            keyup: function(event) {
                self.keyEvent(event);
            }
        })
        this.$endTextField.on({
            keyup: function(event) {
                self.keyEvent(event);
            }
        })

    }
    Rangeslider.prototype.keyEvent = function(event) {
        var textfield = event.originalEvent.currentTarget
        var inputValue = $(textfield).val();

        //start textfield
        if (textfield == this.$startTextfield[0]) {
            this.changeStartValue(inputValue);
            this.renderStartPoint();
        }
        //end textfield
        else {
            this.changeEndValue(inputValue);
            this.renderEndPoint();
        }
    }
    Rangeslider.prototype.mousedown = function(event) {

        var self = this;
        if (self.eventInfo.isDragging) {
            return;
        };

        var target = event.originalEvent.target;

        //point handling
        if (self.$startPoint[0].contains(target)) {
            self.eventInfo.isStartPoint = true;
        } else if (self.$endPoint[0].contains(target)) {
            self.eventInfo.isEndPoint = true;

        }

        var left = self.$slidebar.offset().left;
        var pageX = event.originalEvent.pageX;

        if (self.eventInfo.isStartPoint || self.eventInfo.isEndPoint) {
            //update value
            var diff = pageX - left;
            var inputValue = self.valueForPixel(diff) + self.min;

            if (self.eventInfo.isStartPoint) {
                self.changeStartValue(inputValue);
            } else {
                self.changeEndValue(inputValue);
            }

            self.render();


            //set data
            self.eventInfo.isDragging = true;
            self.eventInfo.dragStartX = pageX;

            activeSlider = self;
        } else if (self.$slidebar[0].contains(target)) { //click slide bar

            var diff = pageX - left;
            var inputValue = self.valueForPixel(diff) + self.min;

            if (inputValue < self.startValue) { //move start point 
                self.changeStartValue(inputValue);
            } else
            if (inputValue > self.endValue) { // move end point
                self.changeEndValue(inputValue);
            } else if (Math.abs(inputValue - self.startValue) < Math.abs(inputValue - self.endValue)) {
                //start 쪽이 더 가까우면 그쪽으로 변경한다. 
                self.changeStartValue(inputValue);
            } else {
                self.changeEndValue(inputValue);

            }

            self.render();

        }

    }

    Rangeslider.prototype.mousemove = function(event) {
        var self = this;

        if (!self.eventInfo.isDragging) {
            return;
        };

        var diff = event.originalEvent.pageX - self.eventInfo.dragStartX;
        //diff가 2px보다 클때 ? min을 2px로 잡음 (더크게 해야 하나?)
        if (Math.abs(diff) > 2) {
            if (self.eventInfo.isStartPoint) {
                var inputValue = self.valueForPixel(diff) + self.startValue;
                self.changeStartValue(inputValue);
            } else if (self.eventInfo.isEndPoint) {
                var inputValue = self.valueForPixel(diff) + self.endValue;
                self.changeEndValue(inputValue);
            }

            self.render();
        }

        self.eventInfo.dragStartX = event.originalEvent.pageX;

    }

    Rangeslider.prototype.mouseup = function(event) {
        var self = this;

        if (self.eventInfo.isDragging) {
            self.eventInfo.isDragging = false;
            self.eventInfo.dragStartX = null;
            self.eventInfo.isStartPoint = false;
            self.eventInfo.isEndPoint = false;

            activeSlider = null;
        };

    }

    Rangeslider.prototype.touchStart = function(event) {
        var self = this;
        if (self.eventInfo.isTouching) {
            return;
        };

        var target = event.originalEvent.target;

        //point handling
        if (self.$startPoint[0].contains(target)) {
            self.eventInfo.isStartPoint = true;
        } else if (self.$endPoint[0].contains(target)) {
            self.eventInfo.isEndPoint = true;

        }
        activeSlider = self;

        //set touch start info
        self.eventInfo.isTouching = true;
        self.eventInfo.touchStartX = event.originalEvent.changedTouches[0].pageX;
    }
    Rangeslider.prototype.touchMove = function(event) {
        var self = this;

        if (!self.eventInfo.isTouching) {
            return;
        };


        var currentX = event.originalEvent.changedTouches[0].pageX;
        var diff = currentX - self.eventInfo.touchStartX;
        //diff가 2px보다 클때 ? min을 2px로 잡음 (더크게 해야 하나?)
        if (Math.abs(diff) > 2) {

            if (self.eventInfo.isStartPoint) {
                var inputValue = self.valueForPixel(diff) + self.startValue;
                self.changeStartValue(inputValue);
            } else if (self.eventInfo.isEndPoint) {
                var inputValue = self.valueForPixel(diff) + self.endValue;
                self.changeEndValue(inputValue);
            }

            self.render();
        };

        self.eventInfo.touchStartX = currentX;
    }

    Rangeslider.prototype.touchEnd = function(event) {
        var self = this;

        //reset touch event info
        if (self.eventInfo.isTouching) {
            self.eventInfo.isTouching = false;
            self.eventInfo.touchStartX = null;
            self.eventInfo.isStartPoint = false;
            self.eventInfo.isEndPoint = false;

            activeSlider = null;
        };

    }

    Rangeslider.prototype.valueForPixel = function(pixel) {
        return Math.round(this.size * pixel / this.$slidebar.width());
    }

    //SET VALUE

    Rangeslider.prototype.changeStartValue = function(value) {
        var self = this;

        if (value == self.startValue) {
            return;
        };

        var input;

        //check min, max
        if (value > self.max) {
            input = self.max;
        } else if (value < self.min) {
            input = self.min;
        } else {
            input = value;
        }

        //check endvalue
        if (input > self.endValue) {
            input = self.endValue;
        };

        self.startValue = input;
    }

    Rangeslider.prototype.changeEndValue = function(value) {
        var self = this;

        if (value == self.endValue) {
            return;
        };

        var input;

        //check min, max
        if (value > self.max) {
            input = self.max;
        } else if (value < self.min) {
            input = self.min;
        } else {
            input = value;
        }

        //check endvalue
        if (input < self.startValue) {
            input = self.startValue;
        };

        self.endValue = input;
    }

    //RENDERING RANGE SLIDE

    Rangeslider.prototype.renderStartPoint = function() {
        var self = this;
        var left = (self.startValue - self.min) / (self.max - self.min) * 100;
        self.$innerbar.css('left', left + '%');
    }

    Rangeslider.prototype.renderEndPoint = function() {
        var self = this;
        var width = (self.endValue - self.startValue) / (self.max - self.min) * 100;
        self.$innerbar.css('width', width + '%');
    }

    Rangeslider.prototype.renderStartTextField = function() {
        if (typeof(this.startValue) == 'undefined' || this.startValue == null) {
            return;
        }
        this.$startTextfield.val(this.startValue);
    }

    Rangeslider.prototype.renderEndTextField = function() {
        if (typeof(this.endValue) == 'undefined' || this.endValue == null) {
            return;
        }
        this.$endTextField.val(this.endValue);
    }

    Rangeslider.prototype.render = function() {
        var self = this;
        self.renderStartPoint();
        self.renderEndPoint();
        self.renderStartTextField();
        self.renderEndTextField();
    }

    // DOCUMENT EVENT (END - MOUSEUP, TOUCHEND)
    $(document).on({
        mousemove: function(event) {
            if (activeSlider) {
                activeSlider.mousemove(event);
            }
        },
        mouseup: function(event) {
            if (activeSlider) {
                activeSlider.mouseup(event);
            }
        },
        touchmove: function(event) {
            if (activeSlider) {
                activeSlider.touchMove(event);
            }
        },
        touchend: function(event) {
            if (activeSlider) {
                activeSlider.touchEnd(event);
            }
        },
        touchcancle: function(event) {
            if (activeSlider) {
                activeSlider.touchEnd(event);
            }
        }
    });


    // RANGE SLIDE PLUGIN
    function Plugin() {
        return this.each(function() {
            var $this = $(this);
            var rangeslider = $this.data(IU_WIDGET.RANGE_SLIDER);
            if (!rangeslider) {
                rangeslider = new Rangeslider(this);
                $this.data(IU_WIDGET.RANGE_SLIDER, rangeslider);
                rangeslider.init();
            };
        })
    }

    $.fn.rangeslider = Plugin
    $.fn.rangeslider.Constructor = Rangeslider

    // SLIDE READY
    $(document).ready(function() {
        $('.iu-pg-range-slide').rangeslider();

    });

}(jQuery)


/*
 * IUEditor : IUSlider 
 * Needs plugin : jQuery, plugin/jquery.iu
 */

+ function($) {

    'use strict';

    var Slide = function(element) {
        //slide elements
        this.$element = $(element)
        this.$point = $(element).find('.iu-pg-slide-point')
        this.$textfield = $(element).find('.iu-pg-slide-text-field')
        this.$slidebar = $(element).find('.iu-pg-slide-bar')
        this.$innerbar = $(element).find('.iux-pg-slidebar-innerbar')

        //call back fn
        this.renderCallbackFn;

        //data
        this.max = parseInt($(element).data('iu-slide-max-value'))
        this.min = parseInt($(element).data('iu-slide-min-value'))
        this.size = this.max - this.min
        this.value = parseInt($(element).data('iu-slide-default-value'))

        //data for event
        this.eventInfo = {
            isTouching: false,
            touchStartX: null,
            isDragging: false,
            dragStartX: null
        }
    }

    var activeSlider = null;

    Slide.prototype.init = function() {

        //set event delegate
        var self = this;
        //TODO : isMobile?을 체크해야 하나? 그냥 다쓰면안되는건가?
        var bindingOption = {
            touchstart: function(event) {
                self.touchStart(event);
                event.preventDefault();
            },
            touchmove: function(event) {
                self.touchMove(event);
                event.preventDefault();
            },
            touchend: function(event) {
                self.touchEnd(event);
                event.preventDefault();
            },
            touchcancle: function(event) {
                self.touchEnd(event);
                event.preventDefault();
            },
            mousedown: function(event) {
                self.mousedown(event);
                event.preventDefault();
            },
            mousemove: function(event) {
                self.mousemove(event);
                event.preventDefault();
            },
            mouseup: function(event) {
                self.mouseup(event);
                event.preventDefault();
            }
        }

        this.$slidebar.on(bindingOption);

        this.$textfield.on({
            keyup: function(event) {
                self.keyEvent(event);
            }
        })

    }
    Slide.prototype.keyEvent = function(event) {
        var inputValue = this.$textfield.val();
        this.setValue(inputValue);
        this.renderPoint();

    }
    Slide.prototype.mousedown = function(event) {
        var self = this;
        if (self.eventInfo.isDragging) {
            return;
        };


        var diff = event.originalEvent.pageX - self.$innerbar.offset().left;
        var inputValue = self.valueForPixel(diff) + self.min;
        self.setValue(inputValue);
        self.render();

        //set data
        self.eventInfo.isDragging = true;
        self.eventInfo.dragStartX = event.originalEvent.pageX;

        activeSlider = self;
    }

    Slide.prototype.mousemove = function(event) {
        var self = this;
        if (!self.eventInfo.isDragging) {
            return;
        };

        var diff = event.originalEvent.pageX - self.eventInfo.dragStartX;
        //diff가 2px보다 클때 ? min을 2px로 잡음 (더크게 해야 하나?)
        if (Math.abs(diff) > 2) {
            var inputValue = self.valueForPixel(diff) + self.value;
            self.setValue(inputValue);
            self.render();
        }

        self.eventInfo.dragStartX = event.originalEvent.pageX;

    }

    Slide.prototype.mouseup = function(event) {
        if (this.eventInfo.isDragging) {
            this.eventInfo.isDragging = false;
            this.eventInfo.dragStartX = null;
            activeSlider = null;
        };

    }

    Slide.prototype.touchStart = function(event) {
        var self = this;
        if (self.eventInfo.isTouching) {
            return;
        };
        activeSlider = self;

        //set touch start info
        self.eventInfo.isTouching = true;
        self.eventInfo.touchStartX = event.originalEvent.changedTouches[0].pageX;
    }
    Slide.prototype.touchMove = function(event) {
        var self = this;

        if (!self.eventInfo.isTouching) {
            return;
        };

        var currentX = event.originalEvent.changedTouches[0].pageX;
        var diff = currentX - self.eventInfo.touchStartX;
        //diff가 2px보다 클때 ? min을 2px로 잡음 (더크게 해야 하나?)
        if (Math.abs(diff) > 2) {
            var inputValue = self.valueForPixel(diff) + self.value;
            self.setValue(inputValue);
            self.render();
        };

        self.eventInfo.touchStartX = currentX;
    }

    Slide.prototype.touchEnd = function(event) {
        //reset touch event info
        if (this.eventInfo.isTouching) {
            this.eventInfo.isTouching = false;
            this.eventInfo.touchStartX = null;
            activeSlider = null;
        };

    }

    Slide.prototype.valueForPixel = function(pixel) {
        return Math.round(this.size * pixel / this.$slidebar.width());
    }

    Slide.prototype.setValue = function(value) {
        var self = this;
        if (value == self.value) {
            return;
        };

        var input;

        //check min, max
        if (value > self.max) {
            input = self.max;
        } else if (value < self.min) {
            input = self.min;
        } else {
            input = value;
        }

        self.value = input;

    }

    Slide.prototype.renderPoint = function() {
        var self = this;
        //set innerbar width
        var size = (self.value - self.min) / (self.max - self.min) * 100;
        self.$innerbar.css('width', size + '%');
    }

    Slide.prototype.renderTextField = function() {
        //set text field
        if (typeof(this.value) == 'undefined' || this.value == null) {
            return;
        }
        this.$textfield.val(this.value);
    }

    Slide.prototype.render = function() {
        var self = this;
        self.renderPoint();
        self.renderTextField();

        if (self.renderCallbackFn) {
            self.renderCallbackFn.call(this);
        };
    }

    Slide.prototype.setRenderCallBackFn = function(callback) {
        if ($.isFunction(callback)) {
            this.renderCallbackFn = callback;
        }
    }

    // DOCUMENT EVENT (END - MOUSEUP, TOUCHEND)
    $(document).on({
        mousemove: function(event) {
            if (activeSlider) {
                activeSlider.mousemove(event);
            }
        },
        mouseup: function(event) {
            if (activeSlider) {
                activeSlider.mouseup(event);
            }
        },
        touchmove: function(event) {
            if (activeSlider) {
                activeSlider.touchMove(event);
            }
        },
        touchend: function(event) {
            if (activeSlider) {
                activeSlider.touchEnd(event);
            }
        },
        touchcancle: function(event) {
            if (activeSlider) {
                activeSlider.touchEnd(event);
            }
        }
    });


    // SLIDE PLUGIN
    function Plugin() {
        return this.each(function() {
            var $this = $(this);
            var slide = $this.data(IU_WIDGET.SLIDER);
            if (!slide) {
                slide = new Slide(this);
                $this.data(IU_WIDGET.SLIDER, slide);
                slide.init();
            };
        })
    }

    $.fn.slide = Plugin
    $.fn.slide.Constructor = Slide

    // SLIDE READY
    $(document).ready(function() {
        $('.iu-pg-slide').slide();
    })

}(jQuery);



/*
 * IUEditor : IUTabView 
 * Needs plugin : jQuery, plugin/jquery.iu
 */
+ function($) {
    'user strict';

    //class
    //tab
    var IU_TAB_HEADER_ITEM_CLASS = '.iu-tab-header-item';
    var IU_TAB_HEADER_ACTIVE_ITEM_CLASS = '.iu-tab-header-active-item';
    var IU_TAB_HEADER_DEFAULT_ITEM_CLASS = '.iu-tab-header-default-item';
    var IU_TAB_CONTENT_ITEM_CLASS = '.iu-tab-content-item';

    //simple tab
    var IU_SIMPLE_TAB_BUTTON_CLASS = '.iu-simple-tab-button';

    //general
    var IU_ACTIVE_CLASS_NAME = 'iux-active';


    var TabView = function(element, type) {
        this.$element = $(element)
            //init 함수에서 setting
        this.selectedIndex = -1
        this.$header = $(element.children[0]);
        this.$content = $(element.children[1]);
        // content items
        this.$items = this.$content.children().filter(IU_TAB_CONTENT_ITEM_CLASS);
        /**
        type 0 : iu tabview
        type 1 : iu simple tabview 
        */
        this.type = type
        this.animation = $(element).data('iu-show-animation');
        var duration = $(element).data('iu-show-duration');
        this.duration = duration ? parseFloat(duration) * 1000 : 0;
    }

    TabView.prototype.init = function() {
        var self = this;
        var initialIndex = 0;
        
        //check contain current link path 
        var linkId = window.location.hash.substring(1);
        var linkHash =  document.getElementById(linkId);
        if ($.contains(self.$element, linkHash)) {
            //check header items
            var index = -1;
            self.$header.children().each(function(i) {
                    if ($.containts(this, linkHash)) {
                        index = i;
                        return false;
                    };
                })
                //check content item
            if (index < 0) {
                self.$items.each(function(i) {
                    if ($.containts(this, linkHash)) {
                        index = i;
                        return false;
                    };
                })

            };
            initialIndex = index;
        }

        //initialize
        self.select(initialIndex, 0, false);

        //event delegate
        if (self.type == 0) {
            self.$header.children().filter(IU_TAB_HEADER_ITEM_CLASS).each(function(i) {
                $(this).on({
                    click: function() {
                        self.select(i);

                    }
                });
            });
        } else if (self.type == 1) {
            self.$header.children().filter(IU_SIMPLE_TAB_BUTTON_CLASS).each(function(i) {
                $(this).on({
                    click: function() {
                        self.select(i);

                    }
                });
            });
        }
    }

    TabView.prototype.select = function(index, duration, autoWindowScroll) {
        var self = this;

        //check index
        if (self.selectedIndex == index) {
            return;
        };

        // set header
        // 1. tabview
        if (self.type == 0) {
            var headerItems = self.$header.children().filter(IU_TAB_HEADER_ITEM_CLASS);

            if (self.selectedIndex >= 0) {
                var oldSelectedItem = $(headerItems[self.selectedIndex]);
                oldSelectedItem.children().filter(IU_TAB_HEADER_ACTIVE_ITEM_CLASS).css('display', 'none');
                oldSelectedItem.children().filter(IU_TAB_HEADER_DEFAULT_ITEM_CLASS).css('display', 'block');
            } else {
                //all children default setting
                headerItems.children().filter(IU_TAB_HEADER_ACTIVE_ITEM_CLASS).css('display', 'none');
                headerItems.children().filter(IU_TAB_HEADER_DEFAULT_ITEM_CLASS).css('display', 'block');
            }

            var selectedItem = $(headerItems[index]);
            selectedItem.children().filter(IU_TAB_HEADER_ACTIVE_ITEM_CLASS).css('display', 'block');
            selectedItem.children().filter(IU_TAB_HEADER_DEFAULT_ITEM_CLASS).css('display', 'none');

        }
        // 2. simpletabview
        else {
            var buttons = self.$header.children().filter(IU_SIMPLE_TAB_BUTTON_CLASS);
            if (self.selectedIndex >= 0) {
                $(buttons[self.selectedIndex]).removeClass(IU_ACTIVE_CLASS_NAME);
            } else {
                buttons.removeClass(IU_ACTIVE_CLASS_NAME);
            }
            $(buttons[index]).addClass(IU_ACTIVE_CLASS_NAME);
        }

        //set content
        if (self.selectedIndex >= 0) {
            var oldContent = $(self.$content.children()[self.selectedIndex]);
            oldContent.css('display', 'none');
            oldContent.finish();
            oldContent.removeClass(IU_ACTIVE_CLASS_NAME);
        } else {
            self.$content.children().css('display', 'none');
            self.$content.children().finish();
            self.$content.children().removeClass(IU_ACTIVE_CLASS_NAME);
        }

        var $selectedContent = $(self.$content.children()[index]);
        $selectedContent.addClass('iu-active');

        var option;
        if (index > self.selectedIndex) {
            option = {
                direction: 'right'
            };
        } else {
            option = {
                direction: 'left'
            };
        }

        //check tab is in window
        var autoScroll = true;
        if (typeof(autoWindowScroll) === 'boolean') {
            autoScroll = autoWindowScroll;
        }
        if (autoScroll) {
            var wScrollTop = $(window).scrollTop();
            var wHeight = $(window).height();
            var top = self.$element.offset().top;
            var isInWindow = top >= wScrollTop && top <= wScrollTop + wHeight ? true : false;

            if (isInWindow == false) {
                //move to header -scroll
                $('body').animate({
                    scrollTop: top
                }, 0);
            };
        }


        //show selected item 
        var currentDuration = duration != null ? duration : self.duration
        $selectedContent.velocityToggle(true, self.animation, currentDuration, option);

        //set index
        self.selectedIndex = index;

    }



    // TABVIEW PLUGIN
    function Plugin(type) {
        return this.each(function() {
            var $this = $(this);
            var tabview = $this.data(IU_WIDGET.TABVIEW);
            if (!tabview) {
                tabview = new TabView(this, type);
                $this.data(IU_WIDGET.TABVIEW, tabview);
                tabview.init();
            };
        })
    }

    $.fn.tabview = Plugin
    $.fn.tabview.Constructor = TabView

    // TABVIEW READY
    $(document).ready(function() {
        $('.iu-tabview').tabview(0);
        $('.iu-simple-tabview').tabview(2);
    });

}(jQuery)



/*
 * IUEditor : IUText 
 * Needs plugin : jQuery, plugin/jquery.iu
 */
+ function($) {

    'use strict';


    //TEXT PROTOTYPE
    // text는 name이 흔해서 iutext로 변경함.
    var IUText = function(element) {
        this.$element = $(element);
        this.slots = $(element).data('iu-text-slot');
        this.textArray = $(element).data('iu-text');
        this.currentIndex = $(element).data('iu-text-index');
        this.hasLink = false;
    }

    var windowSlotIndex, windowSlots = [];

    IUText.prototype.init = function() {
        var isUpdated = this.updateSlot();
        if (this.$element.children('a').length > 0) {
            this.hasLink = true;
        }
        if (isUpdated) {
            this.updateText();
        };

        //resize시 계산을 최소로 줄이기 위해 data를 유지
        $.each(this.slots, function(index, slot) {
            //check slot 
            if (windowSlots.indexOf(slot[0]) < 0) {
                windowSlots.push(slot[0])
            }
            if (windowSlots.indexOf(slot[1]) < 0) {
                windowSlots.push(slot[1])
            }
        })
    }

    IUText.prototype.updateSlot = function() {

        var self = this;
        var slotarray = self.slots[self.currentIndex];
        var slot = {
            start: slotarray[0],
            end: slotarray[1]
        }

        var width = window.innerWidth;

        if (slot.start <= width && width < slot.end) {
            return false;
        } else if (width >= slot.end) {
            self.currentIndex = self.currentIndex + 1;
            self.updateSlot();
            return true;
        } else if (width < slot.start) {
            self.currentIndex = self.currentIndex - 1;
            self.updateSlot();
            return true;
        }

        return false;

    }

    IUText.prototype.updateText = function(index) {
        var self = this;
        if (typeof index == 'number') {
            self.currentIndex = index;
        };

        var text = self.textArray[self.currentIndex];
        //remove original text
        self.$element.find('p').remove();

        if (self.hasLink) {
            //add new text
            self.$element.children('a').append(text);
        } else {
            //add new text
            self.$element.append(text);
        }
    }

    // WINDOW EVENT
    var IUTextController = function() {
        var iutexts = [];

        function add(iutext) {
            iutexts.push(iutext);
        }

        function updateText() {
            for (var i = iutexts.length - 1; i >= 0; i--) {
                var iutext = iutexts[i];
                var isUpdated = iutext.updateSlot()
                if (isUpdated) {
                    iutext.updateText();
                };
            };
        }
        return {
            add: add,
            updateText: updateText
        }
    }

    var Controller = new IUTextController();

    function indexOfWindowWidth(width) {
        var index;

        for (var i = windowSlots.length - 1; i >= 0; i--) {
            if (width > windowSlots[i]) {
                index = i;
                break;
            }
        };
        return index;
    }

    $(window).resize(function(event) {
        var updateIndex = indexOfWindowWidth(window.innerWidth);
        if (windowSlotIndex != updateIndex) {
            Controller.updateText();
            windowSlotIndex = updateIndex;
        };
    })

    // TEXT PLUGIN
    function Plugin() {
        return this.each(function() {
            var $this = $(this);
            var text = $this.data(IU_WIDGET.TEXT);
            if (!text) {
                text = new IUText(this);
                $this.data(IU_WIDGET.TEXT, text);
                Controller.add(text);
                text.init();
            };
        })
    }

    $.fn.iutext = Plugin
    $.fn.iutext.Constructor = IUText

    // TEXT READY
    $(document).ready(
        function() {
            $('.iu-text[data-iu-text]').iutext();
            $('.iu-cell[data-iu-text]').iutext();
            $('.iu-table-row-cell[data-iu-text]').iutext();
            windowSlots.sort();
            windowSlotIndex = indexOfWindowWidth(window.innerWidth);
        }
    );

}(jQuery)



/*
 * IUEditor : IUTransition 
 * Needs plugin : jQuery, plugin/jquery.iu
 */

+ function($) {

    'use strict';

    var Transition = function(element) {
        this.$element = $(element);
        this.animation = $(element).data('iu-show-animation');
        this.duration = parseFloat($(element).data('iu-show-duration')) * 1000;
        this.state = false; //transition on-off state (on - true, off - false)
        this.isShowing = false;
        this.isClosing = false;
        this.items = this.$element.find('.iu-transition-item');
        this.$offItem = $(this.items[0]);
        this.$onItem = $(this.items[1]);
    }

    Transition.prototype.init = function() {
        var self = this;
        var eventType = this.$element.data('iu-event-method');
        //binding
        //mousehover binding
        if (eventType == 'mouseon') {
            var isMobile = window.mobileAndTabletcheck();
            if (isMobile) {
                self.$element.on({
                    touchstart: function() {
                        if (self.isShowing || self.isClosing) {
                            return;
                        }
                        self.toggle(true);
                    },
                    touchcancel: function() {
                        if (self.isClosing) {
                            return;
                        }
                        self.toggle(false);
                    },
                    touchend: function() {
                        if (self.isClosing) {
                            return;
                        }
                        self.toggle(false);
                    }
                });
            } else {
                self.$element.on({
                    mouseenter: function() {
                        if (self.isShowing || self.isClosing) {
                            return;
                        }
                        self.toggle(true);
                    },
                    mouseleave: function() {
                        if (self.isClosing) {
                            return;
                        }
                        self.toggle(false);
                    }
                });
            }
		}
        //click binding
        else {
			this.$element.on({
				click: function() {
					if (self.isShowing || self.isClosing) {
						return;
					}
					self.toggle();
				}
			})
        }
    }

    Transition.prototype.toggle = function(state) {
        if (state != undefined && this.state == state) {
            //현재 상태랑 같은 경우에는 toggle을 요청하지 않는다.
            return;
        };

        var self = this;

        if (typeof(state) == 'undefined' || state == null) {
            state = !self.state;
        }
        // show second item
        if (state) {
            self.state = true;
            self.isShowing = true;
            self.$onItem.velocityToggle(true, self.animation, self.duration, {}, function() {
                if (!self.isClosing) {
                    self.$offItem.css('visibility', 'hidden');
                }
                self.isShowing = false;
            });
        }
        // hide second item
        else {
            self.state = false;
            self.isClosing = true;
            self.$offItem.css('visibility', 'visible');
            self.$onItem.velocityToggle(false, self.animation, self.duration, {}, function() {
                self.isClosing = false;
            });
        }
    }

    // TRANSITION PLUGIN
    function Plugin() {
        return this.each(function() {
            var $this = $(this);
            var transition = $this.data(IU_WIDGET.TRANSITION);
            if (!transition) {
                transition = new Transition(this);
                $this.data(IU_WIDGET.TRANSITION, transition);
                transition.init();
            };
        })
    }

    $.fn.transition = Plugin
    $.fn.transition.Constructor = Transition

    /**
     * PG Switch (IUTransition을 상속)
     */

    var Switch = function(element) {
        Transition.call(this, element);
        this.state = undefined;
        this.$inputEl = $(element).children('input');
    }

    Switch.prototype = Object.create(Transition);
    Switch.prototype.init = function() {

        var self = this;

        //set initial state
        if (self.$inputEl[0].checked) {
            Transition.prototype.toggle.call(self, true);
        } else {
            Transition.prototype.toggle.call(self, false);

        }

        self.$element.css('visibility', 'visible');

        //click delegation
        self.$element.on({
            click: function() {

				if(recvType == 'S' && recvYn == 'N' && !smsDubleCheck){
					return;
				}

                Transition.prototype.toggle.call(self);
                if (self.state) {
                    self.$inputEl[0].checked = true;
                } else {
                    self.$inputEl[0].checked = false;
                }
            }
        })
    }


    // Switch PLUGIN
    function SwitchPlugin() {
        return this.each(function() {
            var $this = $(this);
            var pgswitch = $this.data(IU_WIDGET.SWITCH);
            if (!pgswitch) {
                pgswitch = new Switch(this);
                $this.data(IU_WIDGET.SWITCH, pgswitch);
                pgswitch.init();
            };
        })
    }


    $.fn.pgswitch = SwitchPlugin
    $.fn.pgswitch.Constructor = Switch


    /**
     * MODULE
     */
    // READY
    $(document).ready(function() {
        //$('.iu-transition').transition();
        //$('.iu-pg-switch').pgswitch();
    });

}(jQuery)

/**
 * IUEditor : IUMovie
 */
+ function($) {
    'user strict';
    var Movie = function(element) {
        this.$element = $(element);
    }

    Movie.prototype.play = function() {
        this.$element[0].play();
    }
    Movie.prototype.pause = function() {
        this.$element[0].pause();
    }
    Movie.prototype.autoplay = function() {
        var self = this;
        if (self.$element.isElementInViewport()) {
            self.play();
        } else {
            self.pause();
        }
    }

    // CATCH SCROLL EVENT
    var hasMovie = false;

    $(window).scroll(function() {
        if (hasMovie) {
            var $elements = $('.iu-movie[data-iu-movie-focus-autoplay]');

            if ($elements.length > 0) {
                $elements.each(function() {
                    var $movie = $(this).data(IU_WIDGET.MOVIE);
                    if ($movie) {
                        $movie.autoplay();
                    };
                });
            };
        }
    })



    // MOVIE PLUGIN
    function Plugin() {
        return this.each(function() { // focus autoplay만 handle
            var $this = $(this);
            var movie = $this.data(IU_WIDGET.MOVIE);
            if (!movie) {
                movie = new Movie(this);
                $this.data(IU_WIDGET.MOVIE, movie);
                hasMovie = true;
            };

            //ready check 
            movie.autoplay();
        })
    }

    $.fn.movie = Plugin
    $.fn.movie.Constructor = Movie

    // Movie READY
    $(document).ready(function() {
        $('.iu-movie[data-iu-movie-focus-autoplay]').movie();
    });

}(jQuery)

/*
 * IUEditor : IUWebMovie 
 * Needs plugin : jQuery, plugin/jquery.iu, 
 * Youtube : https://www.youtube.com/iframe_api
 * Vimeo : //f.vimeocdn.com/js/froogaloop2.min.js
 */
//check youtube iframe is 
var isYouTubeLoaded = false;

+ function($) {

    'use strict';

    var Webmovie = function(element) {
        this.$element = $(element);
        this.type = parseInt($(element).data('iu-web-movie-type')); //0 - youtube, 1 - vimeo
        this.isAutoplay = element.hasAttribute('data-iu-web-movie-focus-autoplay');
        this.player = null;
        this.playerId = $(element).children('iframe')[0].id; //iframe id
        this.isPlaying = false;
        this.loaded = false;
    }


    Webmovie.prototype.ready = function() {
        var self = this;
        if (self.loaded) {
            return
        };

        self.loaded = true;

        if (self.type == 0) {
            var videoId = self.$element.data('iu-web-movie-id');
            self.player = new YT.Player(self.playerId, {
                videoId: videoId,
                events: {
                    'onReady': self.autoplay
                }
            });


        } else { // vimeo
            var vimeo_iframe = $(webmovie).children('iframe')[0];
            self.player = Froogaloop(vimeo_iframe);
            //check autoplay
            if (self.isAutoplay) {
                self.autoplay();
            }
        }



    }

    Webmovie.prototype.play = function() {
        var self = this;
        if (self.type == 0) { // youtube
            //youtube loading is too slow, double check
            if (typeof self.player.playVideo !== 'undefined') {
                self.player.playVideo();
                self.isPlaying = true;
            }
        } else { //vimeo
            self.player.api('play');
            self.isPlaying = true;
        }
    }

    Webmovie.prototype.pause = function() {
        var self = this;
        if (self.type == 0) { // youtube
            //youtube loading is too slow, double check
            if (typeof self.player.pauseVideo !== 'undefined') {
                self.player.pauseVideo();
                self.isPlaying = false;
            }
        } else { //vimeo
            self.player.api('pause');
            self.isPlaying = false;
        }
    }

    Webmovie.prototype.autoplay = function(event) {
        if (event) {
            //call from youtube initialization
            var $iu = $(event.target.getIframe().parentElement);
            var webmovie = $iu.data(IU_WIDGET.WEBMOVIE);
            webmovie.autoplay();
            return;
        };

        var self = this;
        if (self.isAutoplay) {

            var display = self.$element.css('display');
            if (display != 'none') {

                if (self.$element.isElementInViewport()) {
                    self.play();
                } else {
                    self.pause();
                }

            };
        };
    }

    // CATCH SCROLL EVENT
    //TODO : window scroll도 한번더 들어갈 수 있는지 체크할것. webmovie가 있을때만 binding시킬수 있게 
    var hasWebmovie = false;

    $(window).scroll(function() {
        if (hasWebmovie) {
            var $elements = $('.iu-webmovie[data-iu-web-movie-focus-autoplay]');

            if ($elements.length > 0) {
                $elements.each(function() {
                    var $webmovie = $(this).data(IU_WIDGET.WEBMOVIE);
                    if ($webmovie) {
                        //youtube 의 경우에는 늦게 로딩됨.
                        $webmovie.autoplay();
                    };
                });
            };
        }
    })



    // WEBMOVIE PLUGIN
    function Plugin() {
        return this.each(function() { // focus autoplay만 handle
            var $this = $(this);
            var webmovie = $this.data(IU_WIDGET.WEBMOVIE);
            if (!webmovie) {
                webmovie = new Webmovie(this);
                $this.data(IU_WIDGET.WEBMOVIE, webmovie);
                hasWebmovie = true;
                webmovie.ready();
            };
        })
    }

    $.fn.webmovie = Plugin
    $.fn.webmovie.Constructor = Webmovie

    // WEBMOVIE READY
    $(document).ready(function() {
        //vimeo
        $('.iu-webmovie[data-iu-web-movie-focus-autoplay][data-iu-web-movie-type="1"]').webmovie();
        //youtube ready
        if (isYouTubeLoaded) {
            $('.iu-webmovie[data-iu-web-movie-focus-autoplay][data-iu-web-movie-type="0"]').webmovie();
        }
    });

}(jQuery)


// Window Youtube callback
window.onYouTubeIframeAPIReady = function() {
    isYouTubeLoaded = true;
    if (typeof $ !== 'undefined' && typeof $.fn.webmovie !== 'undefined') {
        //youtube ready
        $('.iu-webmovie[data-iu-web-movie-focus-autoplay][data-iu-web-movie-type="0"]').webmovie();
    }
};


/*
 * IUEditor : PGFileUpload 
 * Needs plugin : jQuery, velocity
 */

+ function($) {
    var PG_FILE_UPLOAD_INNERBUTTON_CLASS_NAME = 'iux-pg-file-upload-innerbutton';

    function readyPGFileUpload() {

        return this.each(function() {
            var $element = $(this);
            var checkFileUpload = $element.hasClass(PG_FILE_UPLOAD_INNERBUTTON_CLASS_NAME);
            var isSet = $element.data('iu.pgFileUpload');

            if (checkFileUpload && !isSet) {
                //set activated flag
                $element.data('iu.pgFileUpload', true);
                $element.change(function() {
                    var filename = '<p>' + $element.val().replace(/^.*[\\\/]/, '') + '</p>';
                    $($element.parent().parent().children()[1]).html(filename);

                });
            }
        })
    }

    $.fn.activateFileUpload = readyPGFileUpload
    $(document).ready(function() {
        $('.' + PG_FILE_UPLOAD_INNERBUTTON_CLASS_NAME).activateFileUpload();

    })

}(jQuery)

/* =======================================================================================
 * IUEvent Part
 * =======================================================================================
 */


/*
 * IUEditor : Hover 
 * Needs plugin : jQuery, plugin/jquery.iu
 */
+ function($) {
    var IUX_HOVER_CLASS_NAME = 'iux-hover';
    var IUX_HAS_HOVER_CLASS_NAME = 'iux-has-hover';

    function readyHoverEffect() {
        return this.each(function() {
            var $element = $(this);
            var checkHover = $element.hasClass(IUX_HAS_HOVER_CLASS_NAME);
            var isSet = $element.data('iu.hoverEffect');

            if (checkHover && !isSet) {
                //set activated flag
                $element.data('iu.hoverEffect', true);

                var isMobile = window.mobileAndTabletcheck();
                if (isMobile) {
                    $element.on({
                        touchstart: function() {
                            $element.addClass(IUX_HOVER_CLASS_NAME);
                        },
                        touchcancel: function() {
                            $element.removeClass(IUX_HOVER_CLASS_NAME);
                        },
                        touchend: function() {
                            $element.removeClass(IUX_HOVER_CLASS_NAME);
                        }
                    });
                } else {
                    $element.on({
                        mouseenter: function() {
                            $element.addClass(IUX_HOVER_CLASS_NAME);
                        },
                        mouseleave: function() {
                            $element.removeClass(IUX_HOVER_CLASS_NAME);
                        }
                    });
                }
            }

        });
    }
    $.fn.activateHover = readyHoverEffect

    $(document).ready(function() {
        $('.' + IUX_HAS_HOVER_CLASS_NAME).activateHover();
    })
}(jQuery)


/*
 * IUEditor : Scroll Link 
 * Needs plugin : jQuery, plugin/jquery.iu
 */
+ function($) {
    var IUX_LINK_SCROLL_CLASS_NAME = 'iux-link-scroll';

    function readyScrollLink() {
        return this.each(function() {
            var $element = $(this);
            //check event class
            var checkScroll = $element.hasClass(IUX_LINK_SCROLL_CLASS_NAME);
            var isSet = $element.data('iu.scrollLink');

            if (checkScroll && !isSet) {
                //set activated flag
                $element.data('iu.scrollLink', true);
                $element.on({
                    click: function(event) {
                        var firstchild = $element.children().get(0);
                        var parent = $element.parent()[0];

                        var linkEl;
                        //check child link
                        if (firstchild != undefined && firstchild.href != undefined) {
                            linkEl = firstchild;
                        }
                        //check parent link - e.g.)image type <img>
                        else if (parent.href != undefined) {
                            linkEl = parent;
                        }

                        //check linkEl
                        if (linkEl != undefined) {
                            var linkTarget = $(linkEl).attr('target');
                            if (linkTarget == undefined || linkTarget == '_self') {
                                //find div
                                var divId = linkEl.href.split('#')[1];
                                if (divId) {
                                    var $targetEl = $('#' + divId);
                                    //check if target exist
                                    if ($targetEl.length == 1) {
                                        var offset = $targetEl.offset();
                                        event.preventDefault();
                                        var option = {
                                            easing: 'swing',
                                            duration: 600,
                                            complete: $.noop,
                                            step: $.noop
                                        }
                                        $('html,body').stop().animate({
                                            scrollLeft: offset.left,
                                            scrollTop: offset.top
                                        }, option);
                                    }
                                }
                            }

                        };
                    }
                })

            }
        })
    }

    $.fn.activateScrollLink = readyScrollLink
    $(document).ready(function() {
        $('.' + IUX_LINK_SCROLL_CLASS_NAME).activateScrollLink();
    })

}(jQuery)


/*
 * IUEditor : Event Variable
 * Needs plugin : jQuery
 */

+ function($) {

    //iu class
    var IU_EVENT_HOVER_TRIGGER_CLASS = '.iux-hover-trigger';
    var IU_EVENT_CLICK_TRIGGER_CLASS = '.iux-click-trigger';
    var IU_EVENT_RECEIVER_CLASS = '.iux-event-receiver';

    //data
    var IU_EVENT_DATA_METHOD = 'iu-event-method';
    var IU_EVENT_DATA_ANIMATION = 'iu-show-animation';
    var IU_EVENT_DATA_DURATION = 'iu-show-duration';
    var IU_EVENT_DATA_VARIABLE = 'iu-event-var';

    //event machine w/ event variables
    var IUEventMachine = function() {}

    IUEventMachine.prototype.init = function($element) {

        //set init value of event object
        for (var variable in iuEventVariables) {
            var declare = variable + '=' + iuEventVariables[variable].initial;
            eval(declare);
        };

        //initialize state
        $element.find(IU_EVENT_RECEIVER_CLASS).each(function() {
            var evalValue;
            try {
                var condition = $(this).data(IU_EVENT_DATA_METHOD);
                var method = new Function('return (' + condition + ')');
                var evalValue = method(condition);
            } catch (e) {
                return;
            }
            if (evalValue == false) {
                $(this).hide();
            } else {
                $(this).show();
            }
        });


        var self = this;

        //set event delegation
        $element.find(IU_EVENT_HOVER_TRIGGER_CLASS).each(function() {
            var isSet = $(this).data('iu-event-is-set');
            if (!isSet) {
                $(this).data('iu-event-is-set', true);
                $(this).on({
                    mouseenter: function(e) {
                        self.increase(this);
                    },
                    mouseleave: function(e) {
                        self.decrease(this);
                    }
                })
            }
        });

        $element.find(IU_EVENT_CLICK_TRIGGER_CLASS).each(function() {
            var isSet = $(this).data('iu-event-is-set');
            if (!isSet) {
                $(this).data('iu-event-is-set', true);
                $(this).on({
                    click: function(e) {
                        self.increase(this);
                    }
                })
            };
        });
    }

    IUEventMachine.prototype.run = function(variable) {

        $(IU_EVENT_RECEIVER_CLASS).each(function() {
            var condition = $(this).data(IU_EVENT_DATA_METHOD);
            try {
                if (condition.indexOf(variable) >= 0) {
                    var method = new Function('return (' + condition + ')');
                    var evalValue = method(condition);
                    var animation = $(this).data(IU_EVENT_DATA_ANIMATION);
                    var duration = parseFloat($(this).data(IU_EVENT_DATA_DURATION)) * 1000;
                    if (isNaN(duration)) {
                        duration = 0;
                    }
                    $(this).velocityToggle(evalValue, animation, duration, {});
                };
            } catch (e) {
                return false;
            }
        });

    }

    IUEventMachine.prototype.increase = function(iu) {

        var variable = $(iu).data(IU_EVENT_DATA_VARIABLE);
        var eventObject = iuEventVariables[variable];
        var maximumValue = eventObject.maximum;
        var currentValue = (new Function('return (' + variable + ')'))();

        if (currentValue == maximumValue) {
            eval(variable + '=' + eventObject.initial);
        } else {
            eval(variable + '++');
        }
        this.run(variable);
    }

    IUEventMachine.prototype.decrease = function(iu) {
        var variable = $(iu).data(IU_EVENT_DATA_VARIABLE);
        var eventObject = iuEventVariables[variable];
        var currentValue = (new Function('return (' + variable + ')'))();

        if (currentValue == 0) {
            eval(variable + '=' + eventObject.maximum);
        } else {
            eval(variable + '--');
        }
        this.run(variable);
    }


    function initIUEventMachine($element){
        if (typeof iuEventVariables != 'undefined') {
            var eventmachine = window.iuEventMachine;
            //event variable이 있을때만 event machine을 만든다.
            if (typeof eventmachine == 'undefined') {
                eventmachine = new IUEventMachine();
                //export to window
                window.iuEventMachine = eventmachine;
            };
            eventmachine.init($element);
        };
    }

    window.IUEditor.initIUEventMachine = initIUEventMachine;

    $(document).ready(function() {
        initIUEventMachine($('body'));

    });

}(jQuery)


/*
 * IUEditor : Scroll Event
 * Needs plugin : jQuery, velocity, plugin/jquery.iu
 */

+ function($) {

    'use strict';

    /*
     *
     */
    var IUScrollController = function() {
        var iuevents = [];

        function add(iuscrollevent) {
            iuevents.push(iuscrollevent);
        }

        function render() {
            for (var i = iuevents.length - 1; i >= 0; i--) {
                iuevents[i].updateCurrentAnimator();
                iuevents[i].render();
            };
        }

        return {
            add: add,
            render: render
        }
    }

    var Controller = new IUScrollController();

    /*
     * control window width 
     */
    var windowSlotIndex, windowSlots = [];

    // WINDOW EVENT

    function indexOfWindowWidth(width) {
        var index;

        for (var i = windowSlots.length - 1; i >= 0; i--) {
            if (width > windowSlots[i]) {
                index = i;
                break;
            }
        };
        return index;
    }

    $(window).resize(function(event) {
        var updateIndex = indexOfWindowWidth(window.innerWidth);
        if (windowSlotIndex != updateIndex) {
            //TODO : update media query scroll event css properties
            windowSlotIndex = updateIndex;
            Controller.render();
        };
    })

    $(window).scroll(function() {
        Controller.render();
    })



    /* scroll */
    var IUScrollEvent = function(element) {
        var self = this;
        self.$element = $(element);
        self.animator = $(element).data('iu-scroll-animator');
        /*
        isAnimator indicates to change css properties or display 
        @ true : change css properties
        @ false  : change display (block or none)
        */
        self.isAnimator = self.animator != undefined ? true : false;
        if (self.isAnimator) {
            //update slots
            self.slots = $(element).data('iu-scroll-slot');
            //resize시 계산을 최소로 줄이기 위해 data를 유지
            $.each(self.slots, function(index, slot) {
                //check slot 
                if (windowSlots.indexOf(slot) < 0) {
                    windowSlots.push(slot)
                }
                if (windowSlots.indexOf(slot) < 0) {
                    windowSlots.push(slot)
                }
            })

            self.currentIndex = indexOfWindowWidth(window.innerWidth);
        } else {
            self.animation = self.$element.data('iu-show-animation');
            self.duration = parseFloat(self.$element.data('iu-show-duration')) * 1000;
            if (isNaN(self.duration)) {
                self.duration = 0;
            }
            self.state;
        }


        self.frame = {}; //scroll frame range;

    }

    //Used to replace occurences of {?} with a number.
    //Get from : https://github.com/Prinzhorn/skrollr
    var rxInterpolateString = /\{\?\}/g;

    IUScrollEvent.prototype.init = function() {
        var self = this;
        //set frame
        if (self.isAnimator) {
            var elTop = self.$element.offset().top;
            var elStart = elTop;
            var elHeight = self.$element.height();
            var elEnd = elStart + elHeight;

            var lastCenter = $(document).height() - $(window).height() / 2;

            //element의 위치가 document의 밑에 있어서 center까지 올라오지 않을때.
            if (lastCenter < elEnd) {
                elEnd = lastCenter;
                //top의 위치조차 center까지 올라오지 않을때
                if (elStart > elEnd) {
                    elStart = elEnd - elHeight;
                };
            };

            self.frame = {
                top: elTop,
                start: elStart,
                end: elEnd
            };

            //set current animator
            self.currentAnimator = self.animator[self.currentIndex];

        } else {
            var start = parseFloat(self.$element.data('iu-scroll-from'));
            var end = parseFloat(self.$element.data('iu-scroll-to'));
            if (isNaN(start)) {
                start = 0;
            }
            if (isNaN(end)) {
                end = 100000;
            }
            self.frame = {
                start: start,
                end: end
            }
        }

        self.render(0);
    }

    IUScrollEvent.prototype.getIndex = function(width) {
        var index;
        var self = this;
        var windowWidth = width ? width : window.innerWidth;

        for (var i = self.slots.length - 1; i >= 0; i--) {
            if (windowWidth > self.slots[i]) {
                index = i;
                break;
            }
        };
        return index;
    }


    IUScrollEvent.prototype.updateCurrentAnimator = function(index) {
        var self = this;
        if (self.isAnimator) {
            self.currentIndex = index ? index : self.getIndex();
            self.currentAnimator = self.animator[self.currentIndex];
        }
    }


    IUScrollEvent.prototype.render = function(duration) {
        // check if css will be change
        var isChange = true;

        if (isChange) {
            var self = this;

            if (self.isAnimator) {
                var cssDict = {};
                for (var cssName in self.currentAnimator) {
                    var dict = self.currentAnimator[cssName];
                    var interpolated = self.calcInterpolation(dict.pre, dict.post);
                    cssDict[cssName] = self.cssString(interpolated, dict.format);
                }

                self.$element.css(cssDict);
            } else {
                var isVisible = self.isInWindow();
                if (self.state != isVisible) {
                    self.state = isVisible;
                    var currentDuration = isNaN(duration) ? self.duration : duration;
                    self.$element.velocityToggle(isVisible, self.animation, currentDuration, {});
                };

            }
        };

    }

    IUScrollEvent.prototype.isInWindow = function() {
        var wTop = $(window).scrollTop();

        if (wTop >= this.frame.start && wTop <= this.frame.end) {
            return true;
        }
        return false;
    }

    IUScrollEvent.prototype.progress = function() {
        var scrollTop = $(window).scrollTop();
        var wHeight = $(window).height();
        var center = scrollTop + wHeight / 2;
        var elCenter = (this.frame.start + this.frame.end) / 2;

        var progress;
        if (this.frame.top >= scrollTop + wHeight) {
            //화면에 보이지 않을 때 - bottom
            progress = 0;
        } else if (elCenter < center) {
            //상위로 올라갔을 때.
            progress = 1;
        } else {
            //scroll animation이 진행되고 있을 때 
            progress = 1 - (elCenter - center) / (wHeight / 2);
            //double check 
            if (progress < 0) {
                progress = 0;
            }
        }

        return progress;
    }

    IUScrollEvent.prototype.calcInterpolation = function(pre, post) {

        var progress = this.progress();
        var interpolated = [];
        for (var i = 0; i < pre.length; i++) {
            var result = pre[i] + (post[i] - pre[i]) * progress;
            interpolated.push(result);
        };
        return interpolated;
    }

    IUScrollEvent.prototype.cssString = function(interpolated, format) {
        rxInterpolateString.lastIndex = 0;
        var index = 0;
        return format.replace(rxInterpolateString, function() {
            return interpolated[index++];
        })

    }

    // SCROLL EVENT PLUGIN
    function Plugin() {
        return this.each(function() {
            var $this = $(this);
            var scrollevent = $this.data(IU_WIDGET.SCROLL_EVENT);
            if (!scrollevent) {
                scrollevent = new IUScrollEvent(this);
                $this.data(IU_WIDGET.SCROLL_EVENT, scrollevent);
                Controller.add(scrollevent);
                scrollevent.init();
            };
        })
    }

    $.fn.scrollevent = Plugin
    $.fn.scrollevent.Constructor = IUScrollEvent

    // SCROLL EVENT READY
    $(document).ready(function() {
        //check mobile
        if (window.mobileAndTabletcheck() == false) {
            windowSlots.sort();
            windowSlotIndex = indexOfWindowWidth(window.innerWidth);
            $('.iux-event-scroll').scrollevent();
        };
    });
}(jQuery)


/**
 * IUEditor : WP-MENU
 * Needs plugin : 
 */
+ function($) {
    'use strict';

    var WP_MENU_CLASS = '.iux-wp-menu';
    var WP_TOP_MENU_CLASS_NAME = 'iu-wp-top-menu';
    var WP_SIDE_MENU_CLASS_NAME = 'iu-wp-side-menu';

    var WPMenu = function(element) {
        this.$element = $(element);

        /*
         * ul - li - a 
         *         - ul(submenu) - li -a
         */
        // get menu items from whole menu
        // class from wordpress (children)
        this.$items = $(element).children('.menu-item-has-children');

        // get animation info - default setting / wp attribute not working
        this.animation = 'transition.slideDownIn';
        this.duration = 300;
    };

    WPMenu.prototype.init = function() {
        var self = this;
        var isClick = this.$element.hasClass(WP_SIDE_MENU_CLASS_NAME);
        // sidemenu - click , topmenu - hover

        //event binding
        // click
        if (isClick) {
            this.$items.on({
                click: function(event) {
                    var $targetParentEl = $(event.target.parentElement);
                    // check toggle element (hide/show children)
                    if ($targetParentEl.hasClass('menu-item-has-children')) {
                        self.toggle(this);
                        event.preventDefault();
                    };
                }
            })
        }
        // mouse hover
        else {
            var isMobile = window.mobileAndTabletcheck();
            if (isMobile) {
                self.$items.on({
                    touchstart: function() {
                        self.show(this);
                    },
                    touchcancel: function() {
                        self.close(this);
                    },
                    touchend: function() {
                        self.close(this);
                    }
                });
            } else {
                self.$items.on({
                    mouseenter: function() {
                        self.show(this);
                    },
                    mouseleave: function() {
                        self.close(this);
                    }
                });
            }
        }

    };

    WPMenu.prototype.show = function(item) {
        var self = this;

        var $submenu = $(item).children().filter('ul');
        var state = $submenu.data('state');
        if (state != undefined && state) {
            return;
        };
        $submenu.data('state', true);

        // set animation
        $submenu.velocityToggle(true, self.animation, self.duration);

    }

    WPMenu.prototype.close = function(item) {
        var self = this;

        var $submenu = $(item).children().filter('ul');
        var state = $submenu.data('state');
        if (state != undefined && state == false) {
            return;
        };
        $submenu.data('state', false);

        // set animation
        $submenu.velocityToggle(false, self.animation, self.duration);
    }

    WPMenu.prototype.toggle = function(item) {
        var self = this;

        var $submenu = $(item).children().filter('ul');
        var state = $submenu.data('state');
        if (state == undefined) {
            state = false;
        }
        // set a state
        var nextState = !state;
        if (nextState) {
            self.show(item);
        } else {
            self.close(item);
        }

    }

    // WP-MENU PLUGIN
    function Plugin() {
        return this.each(function() {
            var $this = $(this);
            var wpmenu = $this.data(IU_WIDGET.WP_MENU);
            if (!wpmenu) {
                wpmenu = new WPMenu(this);
                $this.data(IU_WIDGET.WP_MENU, wpmenu);
                wpmenu.init();
            };
        })
    }

    $.fn.wpmenu = Plugin
    $.fn.wpmenu.Constructor = WPMenu

    // WP-MENU READY
    $(document).ready(function() {
        $(WP_MENU_CLASS).wpmenu();

    });

}(jQuery);


function IUDOMReady($object){
    $object.find('.iu-carousel').carousel();
    $object.find('.iu-collapsible').collapsible();
    $object.find('.iu-pg-flip-switch').flipswitch();
    $object.find('.iu-googlemap').googlemap();
    $object.find('.iu-pg-range-slide').rangeslider();
    $object.find('.iu-pg-slide').slide();
    $object.find('.iu-tabview').tabview(0);
    $object.find('.iu-simple-tabview').tabview(1);
    $object.find('.iu-text[data-iu-text]').iutext();
    $object.find('.iu-cell[data-iu-text]').iutext();
    $object.find('.iu-table-row-cell[data-iu-text]').iutext();
    $object.find('.iu-section[data-iu-full-section]').iufullsection();
    $object.find('.iu-transition').transition();
    $object.find('.iu-pg-switch').pgswitch();
    $object.find('.iu-webmovie[data-iu-web-movie-focus-autoplay][data-iu-web-movie-type="0"]').webmovie();
    $object.find('.iu-webmovie[data-iu-web-movie-focus-autoplay][data-iu-web-movie-type="1"]').webmovie();
    $object.find('.iux-pg-file-upload-innerbutton').activateFileUpload();
    $object.find('.iux-has-hover').activateHover();
    $object.find('.iux-link-scroll').activateScrollLink();


    window.IUEditor.initPanelComponent($object);
    window.IUEditor.initPopupComponent($object);
    window.IUEditor.initIUEventMachine($object);

    if (window.mobileAndTabletcheck() == false) {
        $object.find('.iux-event-scroll').scrollevent();
    }
}

